@@ -71,7 +71,7 @@ begin
 end;
 */
 GtkPixmap *TCustomImageList::GetPixmap(int index) {
-	if (index < images.size())
+	if ((unsigned int)index < images.size())
 		return images[index];
 	else	return 0;
 }
