@@ -20,8 +20,12 @@
 #include "editentryfrm.h"
 #include "versesel.h"
 #include "splashfrm.h"
+#include "ModVisFrm.h"
 
 //---------------------------------------------------------------------------
+#ifndef USEOLDRTF
+#pragma link "RxRichEd"
+#endif
 #pragma resource "*.dfm"
 TForm1 *Form1;
 //---------------------------------------------------------------------------
@@ -33,7 +37,10 @@ __fastcall TForm1::TForm1(TComponent* Owner)
 	optionsconf = new SWConfig("./options.conf");
 
 	Lookup->Text = "[ SWORD DDE Lookup ]";
-	Search->Text = "[ SWORD DDE Search ]";    
+	Search->Text = "[ SWORD DDE Search ]";
+     modstates.clear();
+     displays.clear();
+     ctrlstates.clear();
 }
 
 void __fastcall TForm1::DisplayHint(TObject* Sender) 
@@ -44,6 +51,7 @@ void __fastcall TForm1::DisplayHint(TObject* Sender)
 //---------------------------------------------------------------------------
 __fastcall TForm1::~TForm1()
 {
+
 	list <SWDisplay *>::iterator it;
 	int loop;
 
@@ -52,6 +60,7 @@ __fastcall TForm1::~TForm1()
 		delete mainmgr;
 	for (it = displays.begin(); it != displays.end(); it++)
 		delete *it;
+
 	if (layoutconf)
 		delete layoutconf;
 
@@ -59,9 +68,10 @@ __fastcall TForm1::~TForm1()
 		delete optionsconf;
 		
 	for (loop = 0; loop < 10; loop++) {
-		if (ctrlstates[loop]);
+		if (ctrlstates[loop])
 			delete ctrlstates[loop];
 	}
+
 	list <ModState *>::iterator mit;
 	for (mit = modstates.begin(); mit != modstates.end(); mit++) {
 		delete (*mit);
@@ -110,12 +120,15 @@ char TForm1::CreateTextPane(SWModule *mod, char *font) {
 	newrtf->ReadOnly = true;
 	newrtf->PopupMenu = (strcmp(mod->Name(), "N27U4")) ? PopupMenu2 : PopupMenu1;
 	newrtf->OnMouseDown = RTFMouseDown;
+//     newrtf->StreamMode >> smUnicode;
+//     newrtf->Font->Charset = CHINESEBIG5_CHARSET;
 
 	BuildRTFHeader(buf, font, 512);
 	newrtf->RTFHeader = buf;
 
 	if ((sit = optionsconf->Sections.find("Appearance")) != optionsconf->Sections.end()) {
-		newrtf->MarkCurrentVerse = (atoi((*(*sit).second.find("AutoVSColor")).second.c_str())) ? true:false;
+		if ((*sit).second.find("AutoVSColor") != (*sit).second.end())
+			newrtf->MarkCurrentVerse = (atoi((*(*sit).second.find("AutoVSColor")).second.c_str())) ? true:false;
 	}
 	if ((sit = optionsconf->Sections.find("Appearance")) != optionsconf->Sections.end()) {
 		if ((*sit).second.find("FontSize") != (*sit).second.end())
@@ -326,6 +339,33 @@ void __fastcall TForm1::About1Click(TObject *Sender)
 {
 	AboutBox->ShowModal();	
 }
+
+
+String TForm1::TrimJunk(String src) {
+	bool hasDigit = false;
+     bool hasAlpha = false;
+     String retVal = "";
+     
+	char *ch = src.c_str();
+     for (;*ch; ch++) {
+     	if (isdigit(*ch))
+          	hasDigit = true;
+          if (isalpha(*ch))
+          	hasAlpha = true;
+     }
+     for (ch = src.c_str(); *ch; ch++) {
+     	if (hasDigit && !hasAlpha) {	// number
+          	if (isdigit(*ch)) retVal += *ch;
+          }
+          else if (hasAlpha) {	// alpha
+          	if (isalpha(*ch)) retVal += *ch;
+         	}
+          else	retVal += *ch;
+     }
+     return retVal;
+}
+
+
 //---------------------------------------------------------------------------
 void __fastcall TForm1::DictionaryLookup1Click(TObject *Sender)
 {
@@ -337,7 +377,10 @@ void __fastcall TForm1::DictionaryLookup1Click(TObject *Sender)
 	char preChar = 0;
 		
 	if (!rtf->SelLength) {
-		for (wordstart = rtf->SelStart; (wordstart > -1)&&(isdigit(rtf->Text[wordstart])||isalpha(rtf->Text[wordstart])); wordstart--);
+#ifndef USEOLDRTF     
+     	lookupKey = TrimJunk(rtf->WordAtCursor());
+#else
+          while (wordstart = rtf->SelStart;((wordstart > -1)&&(isdigit(ch)||isalpha(ch))); wordstart--);
 		rtf->SelStart = (wordstart > -1) ? wordstart: 0;
 		for (wordstart = rtf->SelStart + 1; (wordstart < rtf->Text.Length())&&(isdigit(rtf->Text[wordstart])||isalpha(rtf->Text[wordstart])); wordstart++);
 		rtf->SelLength = ((wordstart < rtf->Text.Length()) ? wordstart : rtf->Text.Length()) - rtf->SelStart - 1;
@@ -345,6 +388,7 @@ void __fastcall TForm1::DictionaryLookup1Click(TObject *Sender)
 		lookupKey = Trim(rtf->SelText);
 		rtf->SelStart = saveSelStart;
 		rtf->SelLength = 0;
+#endif
 	}
 	else	{
 		preChar = rtf->Text[(rtf->SelStart)?rtf->SelStart:0];
@@ -627,7 +671,30 @@ void __fastcall TForm1::FormShow(TObject *Sender)
 			freeHandLookupoldKeyPress(0, ret);
 		}
 	}
-	
+
+	ConfigEntMap *section;
+     TPageControl *pc = 0;
+    	for (int pcs = 0; pcs < 3; pcs++) {
+     	switch (pcs) {
+          case 0:
+          	pc = PageControl1;
+		     section = &(*layoutconf)["TextView"];
+               break;
+          case 1:
+               pc = PageControl2;
+		     section = &(*layoutconf)["CommentView"];
+               break;
+          case 2:
+          	pc = PageControl3;
+	     	section = &(*layoutconf)["LDView"];
+               break;
+          }
+     	
+          for (int i = 0; i < pc->PageCount; i++) {
+               string heading = pc->Pages[i]->Caption.c_str();
+               pc->Pages[i]->TabVisible = !((*section)[heading.c_str()] == "false");  // !false allows default to be true
+          }
+     }
 }
 
 bool TForm1::hasFeature(SWMgr *mgr, const char *modName, const char *feature) {
@@ -896,17 +963,17 @@ void __fastcall TForm1::Options1Click(TObject *Sender)
 
 	if ((sit = optionsconf->Sections.find("Appearance")) != optionsconf->Sections.end()) {
 		Optionsfrm->CurrentVSColor->Brush->Color = 
-			   atoi((*(*sit).second.find("CurrentVSColorRed")).second.c_str())
-			| (atoi((*(*sit).second.find("CurrentVSColorGreen")).second.c_str()) << 8)
-			| (atoi((*(*sit).second.find("CurrentVSColorBlue")).second.c_str()) << 16);
-		Optionsfrm->AutoVSColor->Checked = ((atoi((*(*sit).second.find("AutoVSColor")).second.c_str()))?true:false);
+			   atoi(sit->second["CurrentVSColorRed"].c_str())
+			| (atoi(sit->second["CurrentVSColorGreen"].c_str()) << 8)
+			| (atoi(sit->second["CurrentVSColorBlue"].c_str()) << 16);
+		Optionsfrm->AutoVSColor->Checked = ((atoi(sit->second["AutoVSColor"].c_str()))?true:false);
 		if ((*sit).second.find("FontSize") != (*sit).second.end())
 			Optionsfrm->UpDown1->Position = atoi((*(*sit).second.find("FontSize")).second.c_str());
 	}
 	
 	if ((sit = optionsconf->Sections.find("Bookmarks")) != optionsconf->Sections.end()) {
-		Optionsfrm->AutoBMPersonal->Checked = ((atoi((*(*sit).second.find("AutoSavePersonal")).second.c_str()))?true:false);
-		Optionsfrm->AutoBMOther->Checked    = ((atoi((*(*sit).second.find("AutoSaveOther")).second.c_str()))?true:false);
+		Optionsfrm->AutoBMPersonal->Checked = ((atoi(sit->second["AutoSavePersonal"].c_str()))?true:false);
+		Optionsfrm->AutoBMOther->Checked    = ((atoi(sit->second["AutoSaveOther"].c_str()))?true:false);
 	}
 
 	
@@ -1042,7 +1109,7 @@ void __fastcall TForm1::FormCreate(TObject *Sender)
 }
 
 
-void TForm1::AddVerseChoices(TPopupMenu *menu, const char *buf, TRichEdit *rtf) {
+void TForm1::AddVerseChoices(TPopupMenu *menu, const char *buf, TRxRichEdit *rtf) {
 	TMenuItem *newitem;
 
 	tmpVerseList = DefaultVSKey.ParseVerseList((char *)buf, DefaultVSKey);
@@ -1187,6 +1254,11 @@ void __fastcall TForm1::RTFMouseDown(TObject *Sender, TMouseButton Button, TShif
 	if (Button == mbRight) {
 		if (!rtf->SelLength)
 			SendMessage(rtf->Handle, WM_LBUTTONDOWN, MK_LBUTTON, MAKELONG(X, Y));
+          TPoint menup, point;
+          point.x = X;
+          point.y = Y;
+          menup = rtf->ClientToScreen(point);
+          rtf->PopupMenu->Popup(menup.x, menup.y);	
 	}
 }
 
@@ -1275,8 +1347,8 @@ void __fastcall TForm1::GlobalOptionChange(TObject *Sender)
 	mainmgr->setGlobalOption(option, value);
 	
 	if ((!stricmp(option, "Strong's Numbers")) && (!stricmp(value, "On"))) {
-		const char *curText = PageControl1->ActivePage->Caption.c_str();
-		if (!hasFeature(mainmgr, curText, "StrongsNumbers")) {
+		string curText = PageControl1->ActivePage->Caption.c_str();
+		if (!hasFeature(mainmgr, curText.c_str(), "StrongsNumbers")) {
 			string tmpval = ((eit = optionsconf->Sections["ModDefaults"].find("StrongsNumbers")) != optionsconf->Sections["ModDefaults"].end())? (*eit).second : (string)"";
 			for (int i = 0; i < PageControl1->PageCount; i++) {
 				if (!stricmp(PageControl1->Pages[i]->Caption.c_str(), tmpval.c_str())) {
@@ -1396,3 +1468,43 @@ void __fastcall TForm1::lbDictKeysClick(TObject *Sender)
 //---------------------------------------------------------------------------
 
 
+void __fastcall TForm1::HideShowModules1Click(TObject *Sender)
+{
+	ConfigEntMap *section;
+     TMenuItem *menuItem = (TMenuItem *)Sender;
+     TPopupMenu *menu = (TPopupMenu *)menuItem->GetParentMenu();
+     TComponent *comp = menu->PopupComponent;
+     TPageControl *pc = 0;
+     
+     if ((comp == PageControl1) || (comp == pnlText)) {
+          pc = PageControl1;
+	     section = &(*layoutconf)["TextView"];
+     }
+     if ((comp == PageControl2) || (comp == pnlComment)) {
+     	pc = PageControl2;
+	     section = &(*layoutconf)["CommentView"];
+     }
+     if ((comp == PageControl3) || (comp == pnlDict)) {
+     	pc = PageControl3;
+     	section = &(*layoutconf)["LDView"];
+     }
+
+     if (!pc) return;	// assert pc
+     	
+	for (int i = 0; i < pc->PageCount; i++) {
+     	string heading = pc->Pages[i]->Caption.c_str();
+     	(*section)[heading.c_str()] = ((pc->Pages[i]->TabVisible) ? "true" : "false");
+     }
+     ModVisForm->mgr = mainmgr;
+	ModVisForm->section = section;
+	if (ModVisForm->ShowModal() == mrOk) {
+          for (int i = 0; i < pc->PageCount; i++) {
+               string heading = pc->Pages[i]->Caption.c_str();
+			pc->Pages[i]->TabVisible = ((*section)[heading.c_str()] == "true");
+          }
+     }	
+}
+//---------------------------------------------------------------------------
+
+
+
