@@ -13,18 +13,24 @@
 #include <strkey.h>
 #include <regex.h>
 #include <listkey.h>
-#include "swdisprtfchap.h"
+#include <swdisprtfchap.h>
 #include <vcl\Buttons.hpp>
 #include <vcl\Menus.hpp>
 #include <vcl\DdeMan.hpp>
-//#include <NMHTML.hpp>
 #include <OleCtrls.hpp>
 #include <ToolWin.hpp>
-//#include <vcl\isp.hpp>
 #include <shellapi.h>
 #include <Graphics.hpp>
 #include <ImgList.hpp>
 #include <jpeg.hpp>
+#include "RxRichEd.hpp"
+
+#ifndef USEOLDRTF
+#include "RxRichEd.hpp"
+#else
+#define TRxRichEdit TRichEdit
+#endif
+
 #include <list>
 #include <vector>
 
@@ -153,6 +159,8 @@ __published:	// IDE-managed Components
 	TSplitter *Splitter3;
 	TRichEdit *DictKeyEdit;
 	TListBox *lbDictKeys;
+	TPopupMenu *PopupMenu4;
+	TMenuItem *HideShowModules1;
 	void __fastcall PageControl1Change(TObject *Sender);
 	void __fastcall btnLookupClick(TObject *Sender);
 	void __fastcall PageControl2Change(TObject *Sender);
@@ -213,6 +221,7 @@ __published:	// IDE-managed Components
 	void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
 	void __fastcall lbDictKeysClick(TObject *Sender);
 	void __fastcall verseLookupClick(TObject *Sender);
+	void __fastcall HideShowModules1Click(TObject *Sender);
 private:	// User declarations
 	list <SWDisplay *> displays;	// so we can delete each display we create
 	list <ModState *> modstates;
@@ -229,7 +238,7 @@ private:	// User declarations
 	void BuildRTFHeader(char *buf, char *font, int max);
 	void AddSectionToMenu(TMenu *menu, TMenuItem *item, TTreeNode *tree);
 	void FillDictKeys();
-	void AddVerseChoices(TPopupMenu *menu, const char *buf, TRichEdit *rtf);
+	void AddVerseChoices(TPopupMenu *menu, const char *buf, TRxRichEdit *rtf);
 	void fillVKeySelector(VerseKey *vk);
 	static bool hasFeature(SWMgr *mgr, const char *modName, const char *feature);
 
@@ -245,6 +254,8 @@ public:		// User declarations
 	void TextKeyChanged();		// updates dependents on TextKeyChanged
 	void RefreshBookmarksMenu(TMenu *menu, TTreeView *tree);
 	void RestoreState(ModState *state);
+	static String TrimJunk(String src);
+     
 	ListKey tmpVerseList;
 	String tmpVerseListCaption;
 };
