@@ -2,6 +2,10 @@
 #include <vcl.h>
 #pragma hdrstop
 
+extern "C" {
+#include <untgz.h>
+}
+
 #include "MainFrm.h"
 #include "StatusFrm.h"
 #include "RemoteMntFrm.h"
@@ -20,6 +24,7 @@
 #include <sys/stat.h>
 #include <dir.h>
 
+
 TMainForm *MainForm;
 
 	
@@ -79,7 +84,13 @@ __fastcall InstallSourceTab::~InstallSourceTab() {
 __fastcall TMainForm::TMainForm(TComponent* Owner)
 	: TForm(Owner)
 {
-	manager = new SWMgr();
+     try {
+	    manager = new SWMgr();
+     }
+     catch (...) {
+           createPathAndFile("./mods.d/globals.conf");           
+           manager = new SWMgr();
+     }
 	installConf = new SWConfig("./InstallMgr.conf");
 	localMgr = 0;
 }
@@ -107,8 +118,7 @@ void __fastcall TMainForm::FormCreate(TObject *Sender) {
 }
 
 
-void TMainForm::refreshPageControl()
-{
+void TMainForm::refreshPageControl() {
 	SectionMap::iterator sources;
 	ConfigEntMap::iterator sourceBegin;
 	ConfigEntMap::iterator sourceEnd;
@@ -118,6 +128,7 @@ void TMainForm::refreshPageControl()
 	}
 	
 	sources = installConf->Sections.find("Sources");
+	passive = (!stricmp((*installConf)["General"]["PassiveFTP"].c_str(), "true"));
 
 	if (sources != installConf->Sections.end()) {
 		sourceBegin = sources->second.lower_bound("FTPSource");
@@ -125,7 +136,8 @@ void TMainForm::refreshPageControl()
 
 		if (sourceBegin != sourceEnd) {
 			while (sourceBegin != sourceEnd) {
-				addSource(new InstallSourceTab(this, sourceBegin->second.c_str(), "FTP"));
+				InstallSourceTab *ist = new InstallSourceTab(this, sourceBegin->second.c_str(), "FTP");
+				addSource(ist);
 				sourceBegin++;
 			}
 		}
@@ -155,7 +167,7 @@ void TMainForm::addSource(InstallSourceTab *ist)
 	newpanel->Height = 25;
 	newbutton->Parent = newpanel;
 	newbutton->Caption = "Refresh from Remote Source";
-	newbutton->Width = 175;
+	newbutton->Width = 210;
 	newbutton->OnClick = RefreshRemoteSource;
 	newbutton->Flat = true;
 	newbutton->Glyph = SpeedButton2->Glyph;
@@ -275,7 +287,8 @@ void TMainForm::fillSourceTree(const char *sourceConf, TTreeView *tree)
 		mgr = localMgr = new SWMgr(sourceConf);
 	}
 	else {
-		InstallSourceTab *ist = (InstallSourceTab *) MainForm->PageControl1->ActivePage->Controls[0];
+     	
+		InstallSourceTab *ist = (InstallSourceTab *) tree->Parent->Controls[0];
 		if (ist->mgr)
 			delete ist->mgr;
 		mgr = ist->mgr = new SWMgr(sourceConf);
@@ -306,6 +319,11 @@ void TMainForm::fillSourceTree(const char *sourceConf, TTreeView *tree)
 		else {
 			secName = "Other";
 		}
+
+		string misc1 = ((entry = sections->second.find("Category")) != sections->second.end()) ? (*entry).second : (string)"";
+          if (misc1.length() > 0)
+             secName = misc1;
+
 		entry = sections->second.find("Description");
 		if (entry != sections->second.end())
 			modDesc = entry->second.c_str();
@@ -328,8 +346,6 @@ void TMainForm::fillSourceTree(const char *sourceConf, TTreeView *tree)
 		}
 
 		if (VersionInfo(sourceVersion.c_str()) > VersionInfo(targetVersion.c_str())) {
-
-
 			for (node = tree->Items->GetFirstNode(); node; node = node->getNextSibling()) {
 				if (!strcmp(node->Text.c_str(), secName.c_str())) {
 					break;
@@ -535,7 +551,7 @@ int TMainForm::removeModule(const char *modName)
 int TMainForm::createParent(const char *pName)
 {
 	char *buf = new char [ strlen(pName) + 1 ];
-	int retCode;
+	int retCode = 0;
 	
 	strcpy(buf, pName);
 	int end = strlen(buf) - 1;
@@ -545,13 +561,15 @@ int TMainForm::createParent(const char *pName)
 		end--;
 	}
 	buf[end] = 0;
-	if (!strlen(buf))
-		return -1;
-		
-	if ((retCode = mkdir(buf))) {
-		createParent(buf);
-		retCode = mkdir(buf);
-	}
+	if (strlen(buf)>0) {
+          if (access(buf, 02)) {  // not exists with write access?
+          	if ((retCode = mkdir(buf))) {
+		         	createParent(buf);
+                    retCode = mkdir(buf);
+               }
+		}
+     }
+     else retCode = -1;
 	delete [] buf;
 	return retCode;
 }
@@ -575,7 +593,13 @@ int TMainForm::copyFileToCWD(const char *sourceDir, const char *fName)
 	string sourcePath = sourceDir;
 	sourcePath += fName;
 
-	return copyFile(sourcePath.c_str(), fName);
+     string dest;
+     dest = manager->prefixPath;
+     if ((manager->prefixPath[strlen(manager->prefixPath)-1] != '\\') && ( manager->prefixPath[strlen(manager->prefixPath)-1] != '/'))
+        dest += "/";
+       dest += fName;
+
+	return copyFile(sourcePath.c_str(), dest.c_str());
 }
 
 
@@ -737,7 +761,8 @@ int TMainForm::installModule(const char *modName, InstallSourceTab *ist)
 								SWConfig *config = new SWConfig(modFile.c_str());
 								if (config->Sections.find(modName) != config->Sections.end()) {
 									delete config;
-									string targetFile = "./mods.d/";
+									string targetFile = manager->configPath; //"./mods.d/";
+                                             targetFile += "/";
 									targetFile += ent->d_name;
 									copyFile(modFile.c_str(), targetFile.c_str());
 									if (cipher) {
@@ -850,13 +875,14 @@ void __fastcall TMainForm::Button2Click(TObject *Sender)	// INSTALL
 }
 
 
-int TMainForm::FTPCopy(InstallSourceTab *ist, const char *src, const char *dest, bool dirTransfer)
+int TMainForm::FTPCopy(InstallSourceTab *ist, const char *src, const char *dest, bool dirTransfer, const char *suffix)
 {
 	StatusForm->ist = ist;
 	StatusForm->src = src;
 	StatusForm->dest = dest;
+     StatusForm->suffix = suffix;
 	StatusForm->dirTransfer = dirTransfer;
-	
+     StatusForm->passive = passive;
 	Application->ProcessMessages();
 	if (StatusForm->ShowModal() == mrCancel)
 		return -1;
@@ -872,9 +898,9 @@ void __fastcall TMainForm::RefreshRemoteSource(TObject *Sender)
 	ConfigEntMap::iterator entry;
 	string modDir;
 	string modFile;
-	string target = "./sources/";
-	target += ist->Source.c_str();
-	target += "/mods.d";
+	string root = "./sources/";
+	root += ist->Source.c_str();
+	string target = root + "/mods.d";
 
 	if (dir = opendir(target.c_str())) {
 		rewinddir(dir);
@@ -890,7 +916,13 @@ void __fastcall TMainForm::RefreshRemoteSource(TObject *Sender)
 	}
 
 
-	FTPCopy(ist, "mods.d", target.c_str(), true);
+    	string archive = root + "/mods.d.tar.gz";
+	if (!FTPCopy(ist, "mods.d.tar.gz", archive.c_str(), false)) {
+     	int fd = open(archive.c_str(), O_RDONLY|O_BINARY);
+     	untargz(fd, root.c_str());
+          close(fd);
+     }
+     else	FTPCopy(ist, "mods.d", target.c_str(), true, ".conf");
 
 	target = "./sources/";
 	target += ist->Source.c_str();
@@ -1055,3 +1087,22 @@ void __fastcall TMainForm::LockedModules1Click(TObject *Sender) {
 }
 //---------------------------------------------------------------------------
 
+void __fastcall TMainForm::Contents1Click(TObject *Sender)
+{
+	SWConfig optionsconf("options.conf");
+	string helpDir;
+	ConfigEntMap::iterator it = optionsconf.Sections["Help"].find("Directory");
+	if (it != optionsconf.Sections["Help"].end())
+		helpDir = (*it).second;
+	else helpDir = ".\\help";
+
+	string helpExe = helpDir + "\\sword.chm";
+	
+	if ((int)ShellExecute(this->Handle, "open", helpExe.c_str(), NULL, NULL, SW_SHOWNORMAL) < 33) {
+		helpExe = helpDir + "\\index.html";
+		ShellExecute(this->Handle, "open", helpExe.c_str(), NULL, NULL, SW_SHOWNORMAL);
+	}
+	
+}
+//---------------------------------------------------------------------------
+
