@@ -31,13 +31,13 @@ void __fastcall SWDispRTFChap::Loaded(void)
 
 char SWDispRTFChap::Display(SWModule &Module)
 {
-	int book, chap, verse, versepos;
+	int testmt, book, chap, verse, versepos;
 	System::AnsiString newtext, tmptext;
 	VerseKey *key = (VerseKey *)(SWKey *)Module;
-	
-	chap  = key->Chapter();
-	book  = key->Book();
-	verse = key->Verse();
+	testmt = key->Testament();
+	chap   = key->Chapter();
+	book   = key->Book();
+	verse  = key->Verse();
 	key->Verse(1);
 	newtext = RTFHeader;
 	newtext = newtext + RTFChapterMarkPre + IntToStr(chap) + RTFChapterMarkPost;
@@ -75,6 +75,9 @@ char SWDispRTFChap::Display(SWModule &Module)
 	}
 	newtext = newtext + RTFTrailer;
 	key->Verse(1); //{ When setting chapter: if (verse <> new chapter range) don't autonormalize. (we could've just turned the autonormalize option off then back on, but this is cooler) }
+	key->Chapter(1);
+	key->Book(1);
+	key->Testament(testmt);
 	key->Book(book);
 	key->Chapter(chap);
 	key->Verse(verse);
@@ -84,6 +87,7 @@ char SWDispRTFChap::Display(SWModule &Module)
 	Lines->LoadFromStream(RTFStream);
 
 	//{ Position control text at current verse }
+     this->SetFocus();
 	if (AutoPosition == true) {
 		SelStart = versepos;
 		SendMessage(Handle, EM_SCROLLCARET, 0, 0);
