@@ -1,6 +1,6 @@
 /*
  *
- * $Id: cipherfil.h,v 1.4 2000/05/21 22:30:05 scribe Exp $
+ * $Id: cipherfil.h,v 1.6 2001/02/09 15:38:51 jansorg Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,13 +24,16 @@
 #include <swfilter.h>
 #include <swcipher.h>
 
-class CipherFilter : public SWFilter {
-	SWCipher *cipher;
+#include <defs.h>
+
+class SWDLLEXPORT CipherFilter:public SWFilter
+{
+  SWCipher *cipher;
 public:
-	CipherFilter(const char *key);
-	virtual ~CipherFilter();
-	virtual char ProcessText(char *text, int maxlen, const SWKey *key);
-	virtual SWCipher *getCipher();
+    CipherFilter (const char *key);
+    virtual ~ CipherFilter ();
+  virtual char ProcessText (char *text, int maxlen, const SWKey * key);
+  virtual SWCipher *getCipher ();
 };
 
 #endif
