@@ -16,19 +16,23 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Header: /usr/local/cvsroot/sword/include/gbfhtml.h,v 1.3 1999/10/25 04:31:24 scribe Exp $ */
-/* $Revision: 1.3 $ */
+/* $Header: /usr/local/cvsroot/sword/include/gbfhtml.h,v 1.7 2001/05/25 10:39:07 jansorg Exp $ */
+/* $Revision: 1.7 $ */
 
 #ifndef GBFHTML_H
 #define GBFHTML_H
 
 #include <swfilter.h>
 
-class GBFHTML : public SWFilter {
+#include <defs.h>
+
+/** This filter converts GBF Text into HTML
+ */
+class SWDLLEXPORT GBFHTML:public SWFilter
+{
 public:
-	GBFHTML();
-	virtual char ProcessText(char *text, int maxlen, const SWKey *key);
+  GBFHTML ();
+  virtual char ProcessText (char *text, int maxlen, const SWKey * key);
 };
 
 #endif
-
