@@ -1,6 +1,6 @@
 /*
  *
- * $Id: gbfrtf.h,v 1.3 1999/10/25 04:31:24 scribe Exp $
+ * $Id: gbfrtf.h,v 1.6 2001/02/15 21:20:14 jansorg Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,10 +23,15 @@
 
 #include <swfilter.h>
 
-class GBFRTF : public SWFilter {
+#include <defs.h>
+
+  /** This filter converts GBF text into RTF text
+  */
+class SWDLLEXPORT GBFRTF:public SWFilter
+{
 public:
-	GBFRTF();
-	virtual char ProcessText(char *text, int maxlen, const SWKey *key);
+  GBFRTF ();
+  virtual char ProcessText (char *text, int maxlen, const SWKey * key);
 };
 
 #endif
