@@ -20,11 +20,15 @@
 
 #include <swfilter.h>
 
-class GBFThML : public SWFilter {
+#include <defs.h>
+
+  /** this filter converts GBF text into ThML text
+  */
+class SWDLLEXPORT GBFThML:public SWFilter
+{
 public:
-	GBFThML();
-	virtual char ProcessText(char *text, int maxlen = -1);
+  GBFThML ();
+  virtual char ProcessText (char *text, int maxlen = -1);
 };
 
 #endif
-
