@@ -3,7 +3,7 @@
  *			pointing to actual text desired.  Uses standard
  *			files:	ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * $Id: hrefcom.h,v 1.2 2000/10/15 11:25:31 scribe Exp $
+ * $Id: hrefcom.h,v 1.4 2001/02/09 15:38:51 jansorg Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -27,14 +27,20 @@
 #include <rawverse.h>
 #include <swcom.h>
 
-class HREFCom : public RawVerse, public SWCom {
-	char *versebuf;
-	char *prefix;
+#include <defs.h>
+
+class SWDLLEXPORT HREFCom:public RawVerse, public SWCom
+{
+  char *versebuf;
+  char *prefix;
 
 public:
-	HREFCom(const char *ipath, const char *prefix, const char *iname = 0, const char *idesc = 0, SWDisplay *idisp = 0);
-	virtual ~HREFCom();
-	virtual char *getRawEntry();
+  
+    
+    HREFCom (const char *ipath, const char *prefix, const char *iname =
+	     0, const char *idesc = 0, SWDisplay * idisp = 0);
+    virtual ~ HREFCom ();
+  virtual char *getRawEntry ();
 };
 
 
