@@ -16,18 +16,23 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Header: /usr/local/cvsroot/sword/include/plainhtml.h,v 1.3 1999/10/25 04:31:24 scribe Exp $ */
-/* $Revision: 1.3 $ */
+/* $Header: /usr/local/cvsroot/sword/include/plainhtml.h,v 1.6 2001/02/19 16:59:51 mgruner Exp $ */
+/* $Revision: 1.6 $ */
 
 #ifndef PLAINHTML_H
 #define PLAINHTML_H
 
 #include <swfilter.h>
 
-class PLAINHTML : public SWFilter {
+#include <defs.h>
+
+  /** this filter converts plain text to HTML text
+  */
+class SWDLLEXPORT PLAINHTML:public SWFilter
+{
 public:
-	PLAINHTML();
-	virtual char ProcessText(char *text, int maxlen, const SWKey *key);
+  PLAINHTML ();
+  virtual char ProcessText (char *text, int maxlen, const SWKey * key);
 };
 
 #endif
