@@ -2,7 +2,7 @@
  *  rawcom.h   - code for class 'RawCom'- a module that reads raw commentary
  *			files:	ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * $Id: rawcom.h,v 1.2 2000/10/15 11:25:31 scribe Exp $
+ * $Id: rawcom.h,v 1.5 2001/06/17 21:20:08 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -26,16 +26,23 @@
 #include <rawverse.h>
 #include <swcom.h>
 
-class RawCom : public RawVerse, public SWCom {
+#include <defs.h>
+
+class SWDLLEXPORT RawCom:public RawVerse, public SWCom {
 	char *versebuf;
 
 public:
-	RawCom(const char *ipath, const char *iname = 0, const char *idesc = 0, SWDisplay *idisp = 0);
-	virtual ~RawCom();
-	virtual char *getRawEntry();
+  
+    
+	RawCom (const char *ipath, const char *iname = 0, const char *idesc = 0,
+		SWDisplay * idisp = 0, bool unicode = false);
+     virtual ~ RawCom ();
+     virtual char *getRawEntry ();
 
-	virtual SWModule &operator +=(int increment);
-	virtual SWModule &operator -=(int decrement) { return this->operator +=(-decrement); }
+     virtual SWModule & operator += (int increment);
+     virtual SWModule & operator -= (int decrement) {
+     	return this->operator += (-decrement);
+     }
 };
 
 
