@@ -16,18 +16,23 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Header: /usr/local/cvsroot/sword/include/rwphtml.h,v 1.3 1999/10/25 04:31:24 scribe Exp $ */
-/* $Revision: 1.3 $ */
+/* $Header: /usr/local/cvsroot/sword/include/rwphtml.h,v 1.6 2001/02/15 21:20:14 jansorg Exp $ */
+/* $Revision: 1.6 $ */
 
 #ifndef RWPHTML_H
 #define RWPHTML_H
 
 #include <swfilter.h>
 
-class RWPHTML : public SWFilter {
+#include <defs.h>
+
+  /** this filter converts RWP text to HTML text
+  */
+class SWDLLEXPORT RWPHTML:public SWFilter
+{
 public:
-	RWPHTML();
-	virtual char ProcessText(char *text, int maxlen, const SWKey *key);
+  RWPHTML ();
+  virtual char ProcessText (char *text, int maxlen, const SWKey * key);
 };
 
 #endif
