@@ -1,7 +1,7 @@
 /******************************************************************************
  *  swcipher.h   - definition of Class SWCipher used for data cipher/decipher
  *
- * $Id: swcipher.h,v 1.3 2000/05/21 22:36:02 scribe Exp $
+ * $Id: swcipher.h,v 1.5 2001/02/09 15:38:51 jansorg Exp $
  *
  * Copyright 1999 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,23 +24,26 @@
 
 #include "sapphire.h"
 
-class SWCipher {
+#include <defs.h>
 
-	sapphire master;
-	sapphire work;
+class SWDLLEXPORT SWCipher
+{
 
-	char *buf;
-	bool cipher;
-	int len;
+  sapphire master;
+  sapphire work;
+
+  char *buf;
+  bool cipher;
+  int len;
 protected:
 public:
-	SWCipher(unsigned char *key);
-	virtual void setCipherKey(const char *key);
-	virtual ~SWCipher();
-	virtual char *Buf(const char *buf = 0);
-	virtual char *cipherBuf(unsigned int *len, const char *buf = 0);
-	virtual void Encode(void);
-	virtual void Decode(void);
+    SWCipher (unsigned char *key);
+  virtual void setCipherKey (const char *key);
+    virtual ~ SWCipher ();
+  virtual char *Buf (const char *buf = 0);
+  virtual char *cipherBuf (unsigned int *len, const char *buf = 0);
+  virtual void Encode (void);
+  virtual void Decode (void);
 };
 
 #endif
