@@ -2,7 +2,7 @@
  *  swcom.h   - code for base class 'SWCom'.  SWCom is the basis for all
  *		 types of commentary modules
  *
- * $Id: swcom.h,v 1.1.1.1 1999/05/04 22:03:36 scribe Exp $
+ * $Id: swcom.h,v 1.5 2001/06/17 21:20:08 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -26,11 +26,25 @@
 #include <swmodule.h>
 #include <versekey.h>
 
-class SWCom : public SWModule {
+#include <defs.h>
+
+  /** The basis for all commentary modules
+  */
+class SWDLLEXPORT SWCom : public SWModule {
 public:
-	SWCom(const char *imodname = 0, const char *imoddesc = 0, SWDisplay *idisp = 0);
-	virtual ~SWCom();
-	virtual SWKey *CreateKey() { return new VerseKey(); }
+
+  /** Initializes data for instance of SWCom
+  *
+  * @param imodname Internal name for module
+  * @param imoddesc Name to display to user for module
+  * @param idisp Display object to use for displaying
+  */
+  SWCom(const char *imodname = 0, const char *imoddesc = 0, SWDisplay * idisp = 0, bool unicode = false);
+  virtual ~SWCom();
+  virtual SWKey *CreateKey()
+  {
+    return new VerseKey();
+  }
 };
 
 
