@@ -2,7 +2,7 @@
  *  swtext.h   - code for base class 'SWText'.  SWText is the basis for all
  *		 types of text modules
  *
- * $Id: swtext.h,v 1.1.1.1 1999/05/04 22:03:36 scribe Exp $
+ * $Id: swtext.h,v 1.6 2001/06/17 21:20:08 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -27,11 +27,24 @@
 #include <versekey.h>
 #include <listkey.h>
 
-class SWText : public SWModule {
+#include <defs.h>
+
+/** The basis for all text modules
+ */
+class SWDLLEXPORT SWText:public SWModule
+{
 public:
-	SWText(const char *imodname = 0, const char *imoddesc = 0, SWDisplay *idisp = 0);
-	virtual ~SWText();
-	virtual SWKey *CreateKey();
+  /** Initializes data for instance of SWText
+  *
+  * @param imodname Internal name for module
+  * @param imoddesc Name to display to user for module
+  * @param idisp Display object to use for displaying
+  */
+  SWText (const char *imodname = 0, const char *imoddesc = 0, SWDisplay * idisp = 0, bool unicode = false);
+  virtual ~ SWText ();
+  /** Create the correct key (VerseKey) for use with SWText
+  */
+  virtual SWKey *CreateKey ();
 };
 
 
