@@ -21,11 +21,15 @@
 
 #include <swfilter.h>
 
-class ThMLHTML : public SWFilter {
+#include <defs.h>
+
+  /** this filter converts ThML text to HTML text
+  */
+class SWDLLEXPORT ThMLHTML:public SWFilter
+{
 public:
-	ThMLHTML();
-	virtual char ProcessText(char *text, int maxlen = -1);
+  ThMLHTML ();
+  virtual char ProcessText (char *text, int maxlen = -1);
 };
 
 #endif
-
