@@ -23,10 +23,15 @@
 
 #include <swfilter.h>
 
-class ThMLRTF : public SWFilter {
+#include <defs.h>
+
+  /** this filter converts ThML text to RTF text
+  */
+class SWDLLEXPORT ThMLRTF:public SWFilter
+{
 public:
-	ThMLRTF();
-	virtual char ProcessText(char *text, int maxlen = -1);
+  ThMLRTF ();
+  virtual char ProcessText (char *text, int maxlen = -1);
 };
 
 #endif
