@@ -1,7 +1,7 @@
 /******************************************************************************
  *  utilstr.h	- prototypes for string utility functions
  *
- * $Id: utilstr.h,v 1.1.1.1 1999/05/04 22:03:36 scribe Exp $
+ * $Id: utilstr.h,v 1.5 2001/06/12 06:27:24 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -22,10 +22,14 @@
 #ifndef UTILSTR_H
 #define UTILSTR_H
 
+/** Use stdstr to copy a const char* to a char*
+*/
+char *stdstr (char **iistr, const char *istr);
+char *strstrip (char *istr);
+const char *stristr (const char *s1, const char *s2);
+const char strnicmp(const char *s1, const char *s2, int len);
+unsigned int strlenw(const char *s1);
 
-char *stdstr(char **iistr, const char *istr);
-char *strstrip(char *istr);
-const char *stristr(const char *s1, const char *s2);
 /*
 extern "C" {
 int stricmp(const char *s1, const char *s2);
