@@ -10,6 +10,9 @@
 #include <swkey.h>
 #include <listkey.h>
 
+static const char *classes[] = {"ListKey", "SWKey", "SWObject", 0};
+SWClass ListKey::classdef(classes);
+
 /******************************************************************************
  * ListKey Constructor - initializes instance of ListKey
  *
@@ -19,6 +22,7 @@
 ListKey::ListKey(const char *ikey): SWKey(ikey) {
 	arraymax = 0;
 	ClearList();
+	init();
 }
 
 
@@ -29,8 +33,15 @@ ListKey::ListKey(ListKey const &k) : SWKey(k.keytext) {
 	array = (arraymax)?(SWKey **)malloc(k.arraymax * sizeof(SWKey *)):0;
 	for (int i = 0; i < arraycnt; i++)
 		array[i] = k.array[i]->clone();
+	init();
 }
 
+
+void ListKey::init() {
+	myclass = &classdef;
+}
+
+
 SWKey *ListKey::clone() const
 {
 	return new ListKey(*this);
@@ -108,14 +119,14 @@ ListKey &ListKey::operator <<(const SWKey &ikey)
 
 
 /******************************************************************************
- * ListKey::operator =(POSITION)	- Positions this key
+ * ListKey::operator =(SW_POSITION)	- Positions this key
  *
  * ENT:	p	- position
  *
  * RET:	*this
  */
 
-SWKey &ListKey::operator =(POSITION p)
+SWKey &ListKey::operator =(SW_POSITION p)
 {
 	switch (p) {
 	case 1:	// GCC won't compile P_TOP
@@ -194,7 +205,7 @@ int ListKey::Count()
  * RET:	error status
  */
 
-char ListKey::SetToElement(int ielement, POSITION pos)
+char ListKey::SetToElement(int ielement, SW_POSITION pos)
 {
 	arraypos = ielement;
 	if (arraypos >= arraycnt) {
