@@ -19,6 +19,13 @@
 #include <swkey.h>
 #include <versekey.h>
 #include <localemgr.h>
+extern "C" {
+#include <roman.h>
+}
+
+
+static const char *classes[] = {"VerseKey", "SWKey", "SWObject", 0};
+SWClass VerseKey::classdef(classes);
 
 /******************************************************************************
  *  Initialize static members of VerseKey
@@ -38,6 +45,7 @@ VerseKey::LocaleCache   VerseKey::localeCache;
  */
 
 void VerseKey::init() {
+	myclass = &classdef;
 	if (!instance)
 		initstatics();
 
@@ -119,8 +127,7 @@ SWKey *VerseKey::clone() const
  * ENT:	ikey - text key
  */
 
-VerseKey::~VerseKey()
-{
+VerseKey::~VerseKey() {
 	if (upperBound)
 		delete upperBound;
 	if (lowerBound)
@@ -251,19 +258,22 @@ char VerseKey::parse()
 
 void VerseKey::freshtext() const
 {
-	char buf[254];
+	char buf[2024];
 	int realtest = testament;
 	int realbook = book;
 
 	if (book < 1) {
 		if (testament < 1)
 			sprintf(buf, "[ Module Heading ]");
-		else sprintf(buf, "[ Testament %d Heading ]", testament);
+		else sprintf(buf, "[ Testament %d Heading ]", (int)testament);
 	}
 	else {
 		if (realbook > BMAX[realtest-1]) {
 			realbook -= BMAX[realtest-1];
-			realtest++;
+			if (realtest < 2)
+				realtest++;
+			if (realbook > BMAX[realtest-1])
+				realbook = BMAX[realtest-1];
 		}
 		sprintf(buf, "%s %d:%d", books[realtest-1][realbook-1].name, chapter, verse);
 	}
@@ -302,6 +312,11 @@ int VerseKey::getBookAbbrev(char *abbr)
 				min = target;
 			else	max = target;
 		}
+          for (; target > 0; target--) {
+          	if (strncmp(abbr, abbrevs[target-1].ab, abLen))
+               	break;
+          }
+               
 		return (!diff) ? abbrevs[target].book : -1;
 	}
 	else	return -1;
@@ -328,9 +343,8 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 
 	char book[255];
 	char number[255];
-	char tobook = 0;
-	char tonumber = 0;
-	char lastchar = 0;
+	int tobook = 0;
+	int tonumber = 0;
 	int chap = -1, verse = -1;
 	int bookno = 0;
 	VerseKey curkey, lBound;
@@ -386,6 +400,27 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 					}
 					break;
 				}
+
+                    for (loop = strlen(book) - 1; loop+1; loop--) {
+                         if (book[loop] == ' ') {
+                              if (isroman(&book[loop+1])) {
+                                   if (verse == -1) {
+                                        verse = chap;
+								chap = from_rom(&book[loop+1]);
+								book[loop] = 0;
+							}
+						}
+						break;
+					}
+				}
+
+				if ((!stricmp(book, "V")) || (!stricmp(book, "VER"))) {	// Verse abbrev
+                         if (verse == -1) {
+                              verse = chap;
+						chap = VerseKey(tmpListKey).Chapter();
+                              *book = 0;
+                         }
+                    }
 				bookno = getBookAbbrev(book);
 			}
 			if (((bookno > -1) || (!*book)) && ((*book) || (chap >= 0) || (verse >= 0))) {
@@ -447,7 +482,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 						else tmpListKey << (const SWKey &)(const SWKey)(const char *)curkey;
 					}
 					else	if (expandRange) {
-						VerseKey *newElement = dynamic_cast<VerseKey *>(tmpListKey.GetElement());
+						VerseKey *newElement = SWDYNAMIC_CAST(VerseKey, tmpListKey.GetElement());
 						if (newElement) {
 							if (partial > 1)
 								curkey = MAXCHAPTER;
@@ -497,7 +532,6 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 			if (chap == -1)
 				book[tobook++] = toupper(*buf);
 		}
-		lastchar = *buf;
 		buf++;
 	}
 	number[tonumber] = 0;
@@ -526,6 +560,28 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 			}
 			break;
 		}
+
+		for (loop = strlen(book) - 1; loop+1; loop--) {
+          	if (book[loop] == ' ') {
+               	if (isroman(&book[loop+1])) {
+                    	if (verse == -1) {
+                         	verse = chap;
+                              chap = from_rom(&book[loop+1]);
+                              book[loop] = 0;
+                         }
+                    }
+               	break;
+               }
+          }
+               
+		if ((!stricmp(book, "V")) || (!stricmp(book, "VER"))) {	// Verse abbrev.
+			if (verse == -1) {
+				verse = chap;
+				chap = VerseKey(tmpListKey).Chapter();
+				*book = 0;
+			}
+		}
+			
 		bookno = getBookAbbrev(book);
 	}
 	if (((bookno > -1) || (!*book)) && ((*book) || (chap >= 0) || (verse >= 0))) {
@@ -587,7 +643,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 				else tmpListKey << (const SWKey &)(const SWKey)(const char *)curkey;
 			}
 			else if (expandRange) {
-				VerseKey *newElement = dynamic_cast<VerseKey *>(tmpListKey.GetElement());
+				VerseKey *newElement = SWDYNAMIC_CAST(VerseKey, tmpListKey.GetElement());
 				if (newElement) {
 					if (partial > 1)
 						curkey = MAXCHAPTER;
@@ -767,14 +823,14 @@ VerseKey::operator const char *() const
 
 
 /******************************************************************************
- * VerseKey::operator =(POSITION)	- Positions this key
+ * VerseKey::operator =(SW_POSITION)	- Positions this key
  *
  * ENT:	p	- position
  *
  * RET:	*this
  */
 
-SWKey &VerseKey::operator =(POSITION p)
+SWKey &VerseKey::operator =(SW_POSITION p)
 {
 	switch (p) {
 	case POS_TOP:
