@@ -2,7 +2,7 @@
  *  swmgr.cpp   - implementaion of class SWMgr used to interact with an install
  *				base of sword modules.
  *
- * $Id: swmgr.cpp,v 1.22 2000/11/06 12:47:10 scribe Exp $
+ * $Id: swmgr.cpp,v 1.41 2001/06/17 21:20:08 scribe Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -32,23 +32,30 @@
 #include <unixstr.h>
 #endif
 #include <sys/stat.h>
-
-
+#ifndef __VISUALC__
+#include <iostream.h>
+#endif
 #include <swmgr.h>
 #include <rawtext.h>
 #include <rawgbf.h>
 #include <rawcom.h>
 #include <hrefcom.h>
 #include <rawld.h>
+#include <rawld4.h>
 #include <utilfuns.h>
 #include <gbfplain.h>
+#include <thmlplain.h>
 #include <gbfstrongs.h>
 #include <gbffootnotes.h>
+#include <gbfheadings.h>
+#include <gbfmorph.h>
 #include <cipherfil.h>
 #include <rawfiles.h>
 #include <ztext.h>
+#include <zcom.h>
+#include <lzsscomprs.h>
 
-#ifdef ZLIBSUPPORTED
+#ifndef EXCLUDEZLIB
 #include <zipcomprs.h>
 #endif
 
@@ -74,8 +81,19 @@ void SWMgr::init() {
 	optionFilters.insert(FilterMap::value_type("GBFFootnotes", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 
+	tmpFilter = new GBFMorph();
+	optionFilters.insert(FilterMap::value_type("GBFMorph", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
+	tmpFilter = new GBFHeadings();
+	optionFilters.insert(FilterMap::value_type("GBFHeadings", tmpFilter));
+	cleanupFilters.push_back(tmpFilter);
+
 	gbfplain = new GBFPlain();
 	cleanupFilters.push_back(gbfplain);
+
+	thmlplain = new ThMLPlain();
+	cleanupFilters.push_back(thmlplain);
 }
 
 
@@ -108,13 +126,13 @@ SWMgr::SWMgr(const char *iConfigPath, bool autoload) {
 	path = iConfigPath;
 	if ((iConfigPath[strlen(iConfigPath)-1] != '\\') && (iConfigPath[strlen(iConfigPath)-1] != '/'))
 		path += "/";
-	if (existsFile(path.c_str(), "mods.conf")) {
+	if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 		stdstr(&prefixPath, path.c_str());
 		path += "mods.conf";
 		stdstr(&configPath, path.c_str());
 	}
 	else {
-		if (existsDir(path.c_str(), "mods.d")) {
+		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 			stdstr(&prefixPath, path.c_str());
 			path += "mods.d";
 			stdstr(&configPath, path.c_str());
@@ -148,67 +166,44 @@ SWMgr::~SWMgr() {
 }
 
 
-char SWMgr::existsFile(const char *ipath, const char *ifileName)
-{
-	string path = ipath;
-	if ((ipath[strlen(ipath)-1] != '\\') && (ipath[strlen(ipath)-1] != '/'))
-		path += "/";
-	int fd;
-	string filePath = path + ifileName;
-	if ((fd = ::open(filePath.c_str(), O_RDONLY)) > 0) {
-		::close(fd);
-		return 1;
-	}
-	return 0;
-}
-
-
-char SWMgr::existsDir(const char *ipath, const char *idirName)
-{
-	DIR *dir;
-	string path = ipath;
-	if ((ipath[strlen(ipath)-1] != '\\') && (ipath[strlen(ipath)-1] != '/'))
-		path += "/";
-	string filePath = path + idirName;
-	if ((dir = opendir(filePath.c_str()))) {
-		closedir(dir);
-		return 1;
-	}
-	return 0;
-}
-
-
 void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath) {
 	string path;
 	ConfigEntMap::iterator entry;
-	int fd;
 
 	char *envsworddir = getenv ("SWORD_PATH");
 	char *envhomedir  = getenv ("HOME");
 
 	*configType = 0;
 
+#ifndef __VISUALC__
 	// check working directory
 if (debug)
 	cerr << "Checking working directory for mods.conf...";
+#endif
 
-	if (existsFile(".", "mods.conf")) {
+	if (FileMgr::existsFile(".", "mods.conf")) {
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "found\n";
+#endif
 
 		stdstr(prefixPath, "./");
 		stdstr(configPath, "./mods.conf");
 		return;
 	}
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "\nChecking working directory for mods.d...";
+#endif
 
-	if (existsDir(".", "mods.d")) {
+	if (FileMgr::existsDir(".", "mods.d")) {
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "found\n";
+#endif
 
 		stdstr(prefixPath, "./");
 		stdstr(configPath, "./mods.d");
@@ -218,27 +213,33 @@ if (debug)
 
 
 	// check environment variable SWORD_PATH
-
+#ifndef __VISUALC__
 if (debug)
 	cerr << "\nChecking SWORD_PATH...";
+#endif
 
 	if (envsworddir != NULL) {
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "found (" << envsworddir << ")\n";
+#endif
 
 		path = envsworddir;
 		if ((envsworddir[strlen(envsworddir)-1] != '\\') && (envsworddir[strlen(envsworddir)-1] != '/'))
 			path += "/";
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "\nChecking $SWORD_PATH for mods.conf...";
+#endif
 
+		if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 
-		if (existsFile(path.c_str(), "mods.conf")) {
-
+#ifndef __VISUALC__
 if (debug)
 	cerr << "found\n";
+#endif
 
 			stdstr(prefixPath, path.c_str());
 			path += "mods.conf";
@@ -246,13 +247,17 @@ if (debug)
 			return;
 		}
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "\nChecking $SWORD_PATH for mods.d...";
+#endif
 
-		if (existsDir(path.c_str(), "mods.d")) {
+		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "found\n";
+#endif
 
 			stdstr(prefixPath, path.c_str());
 			path += "mods.d";
@@ -265,14 +270,17 @@ if (debug)
 
 	// check for systemwide /etc/sword.conf
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "\nChecking for /etc/sword.conf...";
+#endif
 
-	if ((fd = ::open("/etc/sword.conf", O_RDONLY)) > 0) {
-		::close(fd);
+	if (!::access("/etc/sword.conf", 04)) {
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "found\n";
+#endif
 
 		SWConfig etcconf("/etc/sword.conf");
 		if ((entry = etcconf.Sections["Install"].find("DataPath")) != etcconf.Sections["Install"].end()) {
@@ -280,16 +288,21 @@ if (debug)
 			if (((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '\\') && ((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '/'))
 				path += "/";
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "DataPath in /etc/sword.conf is set to: " << path;
+#endif
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "\nChecking for mods.conf in DataPath ";
+#endif
+			if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 
-			if (existsFile(path.c_str(), "mods.conf")) {
-
+#ifndef __VISUALC__
 if (debug)
 	cerr << "found\n";
+#endif
 
 				stdstr(prefixPath, path.c_str());
 				path += "mods.conf";
@@ -297,13 +310,17 @@ if (debug)
 				return;
 			}
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "\nChecking for mods.d in DataPath ";
+#endif
 
-			if (existsDir(path.c_str(), "mods.d")) {
+			if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "found\n";
+#endif
 
 				stdstr(prefixPath, path.c_str());
 				path += "mods.d";
@@ -317,18 +334,22 @@ if (debug)
 
 	// check ~/.sword/
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "\nChecking home directory for ~/.sword/mods.conf" << path;
+#endif
 
 	if (envhomedir != NULL) {
 		path = envhomedir;
 		if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
 			path += "/";
 		path += ".sword/";
-		if (existsFile(path.c_str(), "mods.conf")) {
+		if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "found\n";
+#endif
 
 			stdstr(prefixPath, "");
 			path += "mods.conf";
@@ -336,13 +357,17 @@ if (debug)
 			return;
 		}
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "\nChecking home directory for ~/.sword/mods.d" << path;
+#endif
 
-		if (existsDir(path.c_str(), "mods.d")) {
+		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 
+#ifndef __VISUALC__
 if (debug)
 	cerr << "found\n";
+#endif
 
 			stdstr(prefixPath, "");
 			path += "mods.d";
@@ -424,7 +449,7 @@ void SWMgr::Load() {
 				if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
 					path += "/";
 				path += ".sword/";
-				if (existsDir(path.c_str(), "mods.d")) {
+				if (FileMgr::existsDir(path.c_str(), "mods.d")) {
 					char *savePrefixPath = 0;
 					char *saveConfigPath = 0;
 					SWConfig *saveConfig = 0;
@@ -453,7 +478,11 @@ void SWMgr::Load() {
 	}
 	else {
 		SWLog::systemlog->LogError("SWMgr: Can't find 'mods.conf' or 'mods.d'.  Try setting:\n\tSWORD_PATH=<directory containing mods.conf>\n\tOr see the README file for a full description of setup options (%s)", (configPath) ? configPath : "<configPath is null>");
+#ifndef WIN32
+		throw "SWMgr: Can't find 'mods.conf' or 'mods.d' .  Try setting:\n\tSWORD_PATH=<directory containing mods.conf>\n\tOr see the README file for a full description of setup options";
+#else
 		exit(-1);
+#endif
 	}
 }
 
@@ -463,8 +492,13 @@ SWModule *SWMgr::CreateMod(string name, string driver, ConfigEntMap &section)
 	string description, datapath, misc1;
 	ConfigEntMap::iterator entry;
 	SWModule *newmod = 0;
+ 	string sourceformat;
+ 	string encoding;
+     bool unicode = false;
 
-	description = ((entry = section.find("Description")) != section.end()) ? (*entry).second : (string)"";
+	sourceformat = ((entry = section.find("SourceType"))  != section.end()) ? (*entry).second : (string)"";
+	encoding = ((entry = section.find("Encoding"))  != section.end()) ? (*entry).second : (string)"";
+	description  = ((entry = section.find("Description")) != section.end()) ? (*entry).second : (string)"";
 	datapath = prefixPath;
 	if ((prefixPath[strlen(prefixPath)-1] != '\\') && (prefixPath[strlen(prefixPath)-1] != '/'))
 		datapath += "/";
@@ -478,27 +512,51 @@ SWModule *SWMgr::CreateMod(string name, string driver, ConfigEntMap &section)
 		datapath += buf2;
 	delete [] buf;
 	
-#ifdef ZLIBSUPPORTED
-	if (!stricmp(driver.c_str(), "zText")) {
-		newmod = new zText(datapath.c_str(), name.c_str(), description.c_str(), zVerse::CHAPTERBLOCKS, new ZipCompress());
-	}
+    	if ((!stricmp(sourceformat.c_str(), "PlainUnicode")) || (!stricmp(encoding.c_str(), "UTF-8")))
+     	unicode = true;
+
+	if ((!stricmp(driver.c_str(), "zText")) || (!stricmp(driver.c_str(), "zCom"))) {
+		SWCompress *compress = 0;
+		int blockType = CHAPTERBLOCKS;
+		misc1 = ((entry = section.find("BlockType")) != section.end()) ? (*entry).second : (string)"CHAPTER";
+		if (!stricmp(misc1.c_str(), "VERSE"))
+			blockType = VERSEBLOCKS;
+		else if (!stricmp(misc1.c_str(), "CHAPTER"))
+			blockType = CHAPTERBLOCKS;
+		else if (!stricmp(misc1.c_str(), "BOOK"))
+			blockType = BOOKBLOCKS;
+
+		misc1 = ((entry = section.find("CompressType")) != section.end()) ? (*entry).second : (string)"LZSS";
+#ifndef EXCLUDEZLIB
+		if (!stricmp(misc1.c_str(), "ZIP"))
+			compress = new ZipCompress();
+		else
 #endif
+		if (!stricmp(misc1.c_str(), "LZSS"))
+			compress = new LZSSCompress();
+		
+		if (compress) {
+			if (!stricmp(driver.c_str(), "zText"))
+				newmod = new zText(datapath.c_str(), name.c_str(), description.c_str(), blockType, compress, 0, unicode);
+			else	newmod = new zCom(datapath.c_str(), name.c_str(), description.c_str(), blockType, compress, 0, unicode);
+		}
+	}
 	
 	if (!stricmp(driver.c_str(), "RawText")) {
-		newmod = new RawText(datapath.c_str(), name.c_str(), description.c_str());
+		newmod = new RawText(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
 	}
 	
 	// backward support old drivers
 	if (!stricmp(driver.c_str(), "RawGBF")) {
-		newmod = new RawText(datapath.c_str(), name.c_str(), description.c_str());
+		newmod = new RawText(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
 	}
 
 	if (!stricmp(driver.c_str(), "RawCom")) {
-		newmod = new RawCom(datapath.c_str(), name.c_str(), description.c_str());
+		newmod = new RawCom(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
 	}
 				
 	if (!stricmp(driver.c_str(), "RawFiles")) {
-		newmod = new RawFiles(datapath.c_str(), name.c_str(), description.c_str());
+		newmod = new RawFiles(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
 	}
 				
 	if (!stricmp(driver.c_str(), "HREFCom")) {
@@ -507,7 +565,14 @@ SWModule *SWMgr::CreateMod(string name, string driver, ConfigEntMap &section)
 	}
 				
 	if (!stricmp(driver.c_str(), "RawLD"))
-		newmod = new RawLD(datapath.c_str(), name.c_str(), description.c_str());
+		newmod = new RawLD(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
+
+	if (!stricmp(driver.c_str(), "RawLD4"))
+		newmod = new RawLD4(datapath.c_str(), name.c_str(), description.c_str(), 0, unicode);
+
+    // if a specific module type is set in the config, use this
+    if ((entry = section.find("Type")) != section.end()) 
+        newmod->Type(entry->second.c_str());
 
 	return newmod;
 }
@@ -593,6 +658,9 @@ void SWMgr::AddStripFilters(SWModule *module, ConfigEntMap &section)
 	if (!stricmp(sourceformat.c_str(), "GBF")) {
 		module->AddStripFilter(gbfplain);
 	}
+	if (!stricmp(sourceformat.c_str(), "ThML")) {
+		module->AddStripFilter(thmlplain);
+	}
 }
 
 
@@ -649,38 +717,40 @@ void SWMgr::InstallScan(const char *dirname)
    string newmodfile;
    string targetName;
  
-	if ((dir = opendir(dirname))) {
-		rewinddir(dir);
-		while ((ent = readdir(dir))) {
-			if ((strcmp(ent->d_name, ".")) && (strcmp(ent->d_name, ".."))) {
-				newmodfile = dirname;
-				if ((dirname[strlen(dirname)-1] != '\\') && (dirname[strlen(dirname)-1] != '/'))
-					newmodfile += "/";
-				newmodfile += ent->d_name;
-				if (configType) {
-					if (config > 0)
-						close(conffd);
-					targetName = configPath;
-					if ((configPath[strlen(configPath)-1] != '\\') && (configPath[strlen(configPath)-1] != '/'))
-						targetName += "/";
-					targetName += ent->d_name;
-					conffd = open(targetName.c_str(), O_WRONLY|O_CREAT, S_IREAD|S_IWRITE);
-				}
-				else {
-					if (conffd < 1) {
-						conffd = open(config->filename.c_str(), O_WRONLY|O_APPEND);
-						if (conffd > 0)
-							lseek(conffd, 0L, SEEK_END);
-					}
-				}
-				AddModToConfig(conffd, newmodfile.c_str());
-				unlink(newmodfile.c_str());
-			}
-		}
-		if (conffd > 0)
-			close(conffd);
-		closedir(dir);
-	}
+	if (!access(dirname, 04)) {
+          if ((dir = opendir(dirname))) {
+               rewinddir(dir);
+               while ((ent = readdir(dir))) {
+                    if ((strcmp(ent->d_name, ".")) && (strcmp(ent->d_name, ".."))) {
+                         newmodfile = dirname;
+                         if ((dirname[strlen(dirname)-1] != '\\') && (dirname[strlen(dirname)-1] != '/'))
+                              newmodfile += "/";
+                         newmodfile += ent->d_name;
+                         if (configType) {
+                              if (config > 0)
+                                   close(conffd);
+                              targetName = configPath;
+                              if ((configPath[strlen(configPath)-1] != '\\') && (configPath[strlen(configPath)-1] != '/'))
+                                   targetName += "/";
+                              targetName += ent->d_name;
+                              conffd = open(targetName.c_str(), O_WRONLY|O_CREAT, S_IREAD|S_IWRITE);
+                         }
+                         else {
+                              if (conffd < 1) {
+                                   conffd = open(config->filename.c_str(), O_WRONLY|O_APPEND);
+                                   if (conffd > 0)
+                                        lseek(conffd, 0L, SEEK_END);
+                              }
+                         }
+                         AddModToConfig(conffd, newmodfile.c_str());
+                         unlink(newmodfile.c_str());
+                    }
+               }
+               if (conffd > 0)
+                    close(conffd);
+               closedir(dir);
+          }
+     }
 }
 
 
