@@ -295,6 +295,8 @@ void LZSSCompress::DeleteNode(short int Node)
  *						The GetChars() and SendChars() functions are
  *						used to separate this method from the actual
  *						i/o.
+ * 		NOTE:			must set zlen for parent class to know length of
+ * 						compressed buffer.
  */
 
 void LZSSCompress::Encode(void)
@@ -648,9 +650,9 @@ void LZSSCompress::Decode(void)
 				r = (short int) ( (r + 1) & (N - 1) );
 			}
 
-			// Add the "len" characters to the output stream.
+			// Add the "len" :characters to the output stream.
 
-			if (SendChars((char *) c, len) != len)
+			if (SendChars((char *) c, len) != (unsigned int)len)
 				break;
 		}
 	}
