@@ -44,9 +44,10 @@ int RawStr::instance = 0;
  *		(e.g. 'modules/texts/rawtext/webster/')
  */
 
-RawStr::RawStr(const char *ipath)
+RawStr::RawStr(const char *ipath, int fileMode)
 {
 	char buf[127];
+	char tries = 1;
 
 	nl = '\n';
 	lastoff = -1;
@@ -57,11 +58,23 @@ RawStr::RawStr(const char *ipath)
 #define O_BINARY 0		// If it hasn't been defined than we probably
 #endif				// don't need it.
 
-	sprintf(buf, "%s.idx", path);
-	idxfd = FileMgr::systemFileMgr.open(buf, O_RDONLY|O_BINARY);
+	if (fileMode == -1) { // try read/write if possible
+		fileMode = O_RDWR;
+		tries = 2;
+	}
+		
+	for (int i = 0; i < tries; i++) {
+		sprintf(buf, "%s.idx", path);
+		idxfd = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
 
-	sprintf(buf, "%s.dat", path);
-	if ((datfd = FileMgr::systemFileMgr.open(buf, O_RDONLY|O_BINARY)) < 0) {
+		sprintf(buf, "%s.dat", path);
+		datfd = FileMgr::systemFileMgr.open(buf, ((!i)?fileMode:O_RDONLY)|O_BINARY);
+
+		if (idxfd->getFd() >= 0)
+			break;
+	}
+
+	if (datfd < 0) {
 		sprintf(buf, "Error: %d", errno);
 		perror(buf);
 	}
@@ -173,7 +186,7 @@ void RawStr::getidxbuf(long ioffset, char **buf)
  * RET: error status
  */
 
-char RawStr::findoffset(const char *ikey, long *start, unsigned short *size, long away)
+char RawStr::findoffset(const char *ikey, long *start, unsigned short *size, long away, long *idxoff)
 {
 	char *trybuf, *targetbuf, *key, quitflag = 0, retval = 0;
 	long headoff, tailoff, tryoff = 0, maxoff = 0;
@@ -234,6 +247,8 @@ char RawStr::findoffset(const char *ikey, long *start, unsigned short *size, lon
 		*start = *size = 0;
 		read(idxfd->getFd(), start, 4);
 		read(idxfd->getFd(), size, 2);
+		if (idxoff)
+			*idxoff = tryoff;
 
 	#ifdef BIGENDIAN
 		#ifndef MACOSX
@@ -256,10 +271,14 @@ char RawStr::findoffset(const char *ikey, long *start, unsigned short *size, lon
 				*start = laststart;
 				*size = lastsize;
 				tryoff = lasttry;
+				if (idxoff)
+					*idxoff = tryoff;
 				break;
 			}
 			read(idxfd->getFd(), start, 4);
 			read(idxfd->getFd(), size, 2);
+			if (idxoff)
+				*idxoff = tryoff;
 
 	#ifdef BIGENDIAN
 		#ifndef MACOSX
@@ -280,6 +299,8 @@ char RawStr::findoffset(const char *ikey, long *start, unsigned short *size, lon
 	else {
 		*start = 0;
 		*size  = 0;
+		if (idxoff)
+			*idxoff = 0;
 		retval = -1;
 	}
 	return retval;
@@ -353,23 +374,41 @@ void RawStr::preptext(char *buf)
  *
  */
 
-void RawStr::gettext(long start, unsigned short size, char *idxbuf, char *buf)
+void RawStr::gettext(long istart, unsigned short isize, char *idxbuf, char *buf)
 {
 	char *ch;
 	char *idxbuflocal = 0;
-	getidxbufdat(start, &idxbuflocal);
+	getidxbufdat(istart, &idxbuflocal);
+	long start = istart;
+	unsigned short size = isize;
 
-	memset(buf, 0, size);
-	lseek(datfd->getFd(), start, SEEK_SET);
-	read(datfd->getFd(), buf, (int)(size - 1));
+	do {
+		memset(buf, 0, size);
+		lseek(datfd->getFd(), start, SEEK_SET);
+		read(datfd->getFd(), buf, (int)(size - 1));
 
-	for (ch = buf; *ch; ch++) {		// skip over index string
-		if (*ch == 10) {
-			ch++;
-			break;
+		for (ch = buf; *ch; ch++) {		// skip over index string
+			if (*ch == 10) {
+				ch++;
+				break;
+			}
 		}
+		memmove(buf, ch, size - (unsigned short)(ch-buf));
+
+		// resolve link
+		if (!strncmp(buf, "@LINK", 5)) {
+			for (ch = buf; *ch; ch++) {		// null before nl
+				if (*ch == 10) {
+					*ch = 0;
+					break;
+				}
+			}
+			findoffset(buf + 6, &start, &size);
+		}
+		else break;
 	}
-	memmove(buf, ch, size - (unsigned short)(ch-buf));
+	while (true);	// while we're resolving links
+
 	if (idxbuflocal) {
 		int localsize = strlen(idxbuflocal);
 		localsize = (localsize < (size - 1)) ? localsize : (size - 1);
@@ -378,3 +417,175 @@ void RawStr::gettext(long start, unsigned short size, char *idxbuf, char *buf)
 		free(idxbuflocal);
 	}
 }
+
+
+/******************************************************************************
+ * RawLD::settext	- Sets text for current offset
+ *
+ * ENT: key	- key for this entry
+ *	buf	- buffer to store
+ */
+
+void RawStr::settext(const char *ikey, const char *buf)
+{
+
+	long start, outstart;
+	long idxoff;
+	long endoff;
+	long shiftSize;
+	unsigned short size;
+	unsigned short outsize;
+	static const char nl[] = {13, 10};
+	char *tmpbuf = 0;
+	char *key = 0;
+	char *dbKey = 0;
+	char *idxBytes = 0;
+	char *outbuf = 0;
+	char *ch = 0;
+
+	findoffset(ikey, &start, &size, 0, &idxoff);
+	stdstr(&key, ikey);
+	for (ch = key; *ch; ch++)
+		*ch = toupper(*ch);
+	ch = 0;
+
+	getidxbufdat(start, &dbKey);
+
+	if (strcmp(key, dbKey) < 0) {
+	}
+	else if (strcmp(key, dbKey) > 0) {
+		idxoff += 6;
+	} else if ((!strcmp(key, dbKey)) && (strlen(buf) /*we're not deleting*/)) { // got absolute entry
+		do {
+			tmpbuf = new char [ size + 2 ];
+			memset(tmpbuf, 0, size + 2);
+			lseek(datfd->getFd(), start, SEEK_SET);
+			read(datfd->getFd(), tmpbuf, (int)(size - 1));
+
+			for (ch = tmpbuf; *ch; ch++) {		// skip over index string
+				if (*ch == 10) {
+					ch++;
+					break;
+				}
+			}
+			memmove(tmpbuf, ch, size - (unsigned short)(ch-tmpbuf));
+
+			// resolve link
+			if (!strncmp(tmpbuf, "@LINK", 5) && strlen(buf)) {
+				for (ch = tmpbuf; *ch; ch++) {		// null before nl
+					if (*ch == 10) {
+						*ch = 0;
+						break;
+					}
+				}
+				findoffset(tmpbuf + 6, &start, &size, 0, &idxoff);
+			}
+			else break;
+		}
+		while (true);	// while we're resolving links
+	}
+
+	endoff = lseek(idxfd->getFd(), 0, SEEK_END);
+
+	shiftSize = endoff - idxoff;
+
+	if (shiftSize > 0) {
+		idxBytes = new char [ shiftSize ];
+		lseek(idxfd->getFd(), idxoff, SEEK_SET);
+		read(idxfd->getFd(), idxBytes, shiftSize);
+	}
+
+	outbuf = new char [ strlen(buf) + strlen(key) + 5 ];
+	sprintf(outbuf, "%s%c%c%s", key, 13, 10, buf);
+	size = outsize = strlen(outbuf);
+
+	start = outstart = lseek(datfd->getFd(), 0, SEEK_END);
+#ifdef BIGENDIAN
+	#ifndef MACOSX
+		outstart = lelong(start);
+		outsize  = leshort(size);
+	#else
+		outstart = NXSwapLittleLongToHost(start);
+		outsize  = NXSwapLittleShortToHost(size);
+	#endif
+#endif
+	lseek(idxfd->getFd(), idxoff, SEEK_SET);
+	if (strlen(buf)) {
+		lseek(datfd->getFd(), start, SEEK_SET);
+		write(datfd->getFd(), outbuf, (int)size);
+
+		// add a new line to make data file easier to read in an editor
+		write(datfd->getFd(), &nl, 2);
+		
+		write(idxfd->getFd(), &outstart, 4);
+		write(idxfd->getFd(), &outsize, 2);
+		if (idxBytes) {
+			write(idxfd->getFd(), idxBytes, shiftSize);
+			delete [] idxBytes;
+		}
+	}
+	else {	// delete entry
+		if (idxBytes) {
+			write(idxfd->getFd(), idxBytes+6, shiftSize-6);
+			lseek(idxfd->getFd(), -1, SEEK_CUR);	// last valid byte
+			FileMgr::systemFileMgr.trunc(idxfd);	// truncate index
+			delete [] idxBytes;
+		}
+	}
+
+	delete [] key;
+	delete [] outbuf;
+	free(dbKey);
+}
+
+
+/******************************************************************************
+ * RawLD::linkentry	- links one entry to another
+ *
+ * ENT: testmt	- testament to find (0 - Bible/module introduction)
+ *	destidxoff	- dest offset into .vss
+ *	srcidxoff		- source offset into .vss
+ */
+
+void RawStr::linkentry(const char *destkey, const char *srckey) {
+	char *text = new char [ strlen(destkey) + 7 ];
+	sprintf(text, "@LINK %s", destkey);
+	settext(srckey, text);
+	delete [] text;
+}
+
+
+/******************************************************************************
+ * RawLD::CreateModule	- Creates new module files
+ *
+ * ENT: path	- directory to store module files
+ * RET: error status
+ */
+
+char RawStr::createModule(const char *ipath)
+{
+	char *path = 0;
+	char *buf = new char [ strlen (ipath) + 20 ];
+	FileDesc *fd, *fd2;
+
+	stdstr(&path, ipath);
+
+	if ((path[strlen(path)-1] == '/') || (path[strlen(path)-1] == '\\'))
+		path[strlen(path)-1] = 0;
+
+	sprintf(buf, "%s.dat", path);
+	unlink(buf);
+	fd = FileMgr::systemFileMgr.open(buf, O_CREAT|O_WRONLY|O_BINARY, S_IREAD|S_IWRITE);
+	fd->getFd();
+	FileMgr::systemFileMgr.close(fd);
+
+	sprintf(buf, "%s.idx", path);
+	unlink(buf);
+	fd2 = FileMgr::systemFileMgr.open(buf, O_CREAT|O_WRONLY|O_BINARY, S_IREAD|S_IWRITE);
+	fd2->getFd();
+	FileMgr::systemFileMgr.close(fd2);
+
+	delete [] path;
+	
+	return 0;
+}
