@@ -52,13 +52,13 @@
 
 RawVerse::RawVerse(const char *ipath, int fileMode)
 {
-	char buf[127];
+	char *buf;
 	int tries = 1;
 
 	nl = '\n';
 	path = 0;
 	stdstr(&path, ipath);
-
+     buf = new char [ strlen(path) + 80 ];
 	if ((path[strlen(path)-1] == '/') || (path[strlen(path)-1] == '\\'))
 		path[strlen(path)-1] = 0;
 
@@ -82,7 +82,7 @@ RawVerse::RawVerse(const char *ipath, int fileMode)
 		if ((idxfp[0]->getFd() >= 0) || (idxfp[1]->getFd() >= 0))
 			break;
 	}
-	
+	delete [] buf;
 	instance++;
 }
 
@@ -207,16 +207,18 @@ void RawVerse::preptext(char *buf)
  *
  * ENT:	testmt	- testament file to search in (0 - Old; 1 - New)
  *	start	- starting offset where the text is located in the file
- *	size	- size of text entry + 1 (null)
+ *	size	- size of text entry + 2 (null)(null)
  *	buf	- buffer to store text
  *
  */
 
 void RawVerse::gettext(char testmt, long start, unsigned short size, char *buf) {
 	memset(buf, 0, size);
-	if (textfp[testmt-1]->getFd() >= 0) {
-		lseek(textfp[testmt-1]->getFd(), start, SEEK_SET);
-		read(textfp[testmt-1]->getFd(), buf, (int)size - 1);
+	if (size) {
+		if (textfp[testmt-1]->getFd() >= 0) {
+			lseek(textfp[testmt-1]->getFd(), start, SEEK_SET);
+			read(textfp[testmt-1]->getFd(), buf, (int)size - 2); 
+		}
 	}
 }
 
