@@ -35,13 +35,13 @@ char GBFHTML::ProcessText(char *text, int maxlen, const SWKey *key)
 	bool isCentered = false;
 	int len;
 
-	len = strlen(text) + 1;						// shift string to right of buffer
+	len = strlen(text) + 1;		// shift string to right of buffer
 	if (len < maxlen) {
 		memmove(&text[maxlen - len], text, len);
 		from = &text[maxlen - len];
 	}
 	else
-		from = text;							// -------------------------------
+		from = text;			// -------------------------------
 	
 	for (to = text; *from; from++)
 	{
@@ -54,8 +54,8 @@ char GBFHTML::ProcessText(char *text, int maxlen, const SWKey *key)
 			memset(token, 0, 2048);
 			continue;
 		}
-		if (*from == '>')
-		{
+		if (*from == '>') {
+			unsigned int i;
 			intoken = false;
 			// process desired tokens
 			switch (*token) {
@@ -64,36 +64,6 @@ char GBFHTML::ProcessText(char *text, int maxlen, const SWKey *key)
 					{
 						case 'G':               // Greek
 						case 'H':               // Hebrew
-							*to++ = ' ';
-							*to++ = '<';
-							*to++ = 'S';
-							*to++ = 'M';
-							*to++ = 'A';
-							*to++ = 'L';
-							*to++ = 'L';
-							*to++ = '>';
-							*to++ = '<';
-							*to++ = 'E';
-							*to++ = 'M';
-							*to++ = '>';
-							for (unsigned int i = 2; i < strlen(token); i++)
-								*to++ = token[i];
-							*to++ = '<';
-							*to++ = '/';
-							*to++ = 'E';
-							*to++ = 'M';
-							*to++ = '>';
-							*to++ = '<';
-							*to++ = '/';
-							*to++ = 'S';
-							*to++ = 'M';
-							*to++ = 'A';
-							*to++ = 'L';
-							*to++ = 'L';
-							*to++ = '>';
-							*to++ = ' ';
-							continue;
-
 						case 'T':               // Tense
 							*to++ = ' ';
 							*to++ = '<';
@@ -104,13 +74,15 @@ char GBFHTML::ProcessText(char *text, int maxlen, const SWKey *key)
 							*to++ = 'L';
 							*to++ = '>';
 							*to++ = '<';
-							*to++ = 'I';
+							*to++ = 'E';
+							*to++ = 'M';
 							*to++ = '>';
-							for (unsigned int i = 3; i < strlen(token); i++)
+							for (i = 2; i < strlen(token); i++)
 								*to++ = token[i];
 							*to++ = '<';
 							*to++ = '/';
-							*to++ = 'I';
+							*to++ = 'E';
+							*to++ = 'M';
 							*to++ = '>';
 							*to++ = '<';
 							*to++ = '/';
@@ -312,6 +284,33 @@ char GBFHTML::ProcessText(char *text, int maxlen, const SWKey *key)
 							*to++ = 'B';
 							*to++ = '>';
 							continue;
+					        case 'N':
+						        *to++ = '<';
+							*to++ = 'f';
+							*to++ = 'o';
+							*to++ = 'n';
+							*to++ = 't';
+							*to++ = ' ';
+							*to++ = 'f';
+							*to++ = 'a';
+							*to++ = 'c';
+							*to++ = 'e';
+							*to++ = '=';
+							*to++ = '"';
+						        for (i = 2; i < strlen(token); i++)
+								*to++ = token[i];
+							*to++ = '"';
+							*to++ = '>';
+							continue;
+					        case 'n':
+						        *to++ = '<';
+							*to++ = '/';
+							*to++ = 'f';
+							*to++ = 'o';
+							*to++ = 'n';
+							*to++ = 't';
+							*to++ = '>';
+							continue;
 					}
 					break;
 				case 'C':			// special character tags
@@ -421,19 +420,46 @@ char GBFHTML::ProcessText(char *text, int maxlen, const SWKey *key)
 					{
 						case 'T':               // Book title begin
 							*to++ = '<';
-							*to++ = 'B';
-							*to++ = 'I';
-							*to++ = 'G';
+							*to++ = 'b';
+							*to++ = 'i';
+							*to++ = 'g';
 							*to++ = '>';
 							continue;
 						case 't':
 							*to++ = '<';
 							*to++ = '/';
-							*to++ = 'B';
-							*to++ = 'I';
-							*to++ = 'G';
+							*to++ = 'b';
+							*to++ = 'i';
+							*to++ = 'g';
 							*to++ = '>';
+							continue;/*
+                    				case 'S':
+						        *to++ = '<';
+						        *to++ = 'b';
+						        *to++ = 'r';
+						        *to++ = ' ';
+						        *to++ = '/';
+						        *to++ = '>';
+						        *to++ = '<';
+						        *to++ = 'b';
+						        *to++ = 'i';
+							*to++ = 'g';
+						        *to++ = '>';
 							continue;
+                    				case 's':
+						        *to++ = '<';
+						        *to++ = '/';
+						        *to++ = 'b';
+						        *to++ = 'i';
+						        *to++ = 'g';
+						        *to++ = '>';
+						        *to++ = '<';
+						        *to++ = 'b';
+						        *to++ = 'r';
+						        *to++ = ' ';
+						        *to++ = '/';
+						        *to++ = '>';
+							continue;*/
 					}
 					break;
 	
@@ -471,6 +497,7 @@ char GBFHTML::ProcessText(char *text, int maxlen, const SWKey *key)
 		else
 			*to++ = *from;
 	}
+	*to++ = 0;
 	*to = 0;
 	return 0;
 }
