@@ -20,6 +20,7 @@ char GBFPlain::ProcessText(char *text, int maxlen, const SWKey *key)
 	int tokpos = 0;
 	bool intoken = false;
 	int len;
+	unsigned int i;
 
 	len = strlen(text) + 1;						// shift string to right of buffer
 	if (len < maxlen) {
@@ -43,20 +44,12 @@ char GBFPlain::ProcessText(char *text, int maxlen, const SWKey *key)
 				switch(token[1]) {
 					case 'G':               // Greek
 					case 'H':               // Hebrew
-						*to++ = ' ';
-						*to++ = '<';
-						for (unsigned int i = 2; i < strlen(token); i++)
-							*to++ = token[i];
-						*to++ = '>';
-						*to++ = ' ';
-						continue;
-
 					case 'T':               // Tense
 						*to++ = ' ';
-						*to++ = '(';
-						for (unsigned int i = 3; i < strlen(token); i++)
+						*to++ = '<';
+						for (i = 2; i < strlen(token); i++)
 							*to++ = token[i];
-						*to++ = ')';
+						*to++ = '>';
 						*to++ = ' ';
 						continue;
 				}
@@ -105,6 +98,7 @@ char GBFPlain::ProcessText(char *text, int maxlen, const SWKey *key)
 		}
 		else	*to++ = *from;
 	}
-	*to = 0;
+	*to++ = 0;
+ 	*to = 0;
 	return 0;
 }
