@@ -7,7 +7,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <gbfrtf.h>
-
+#include <ctype.h>
 
 GBFRTF::GBFRTF() {
 }
@@ -15,18 +15,20 @@ GBFRTF::GBFRTF() {
 
 char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 {
-	char *to, *from, token[2048];
+	unsigned char *to, *from;
+	char token[2048];
 	int tokpos = 0;
 	bool intoken = false;
 	int len;
+	unsigned int i;
 
 	len = strlen(text) + 1;						// shift string to right of buffer
 	if (len < maxlen) {
 		memmove(&text[maxlen - len], text, len);
-		from = &text[maxlen - len];
+		from = (unsigned char *)&text[maxlen - len];
 	}
-	else	from = text;							// -------------------------------
-	for (to = text; *from; from++) {
+	else	from = (unsigned char *)text;							// -------------------------------
+	for (to = (unsigned char *)text; *from; from++) {
 		if (*from == '<') {
 			intoken = true;
 			tokpos = 0;
@@ -49,7 +51,7 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 					*to++ = '7';
 					*to++ = ' ';
 					*to++ = '<';
-					for (unsigned int i = 2; i < strlen(token); i++)
+					for (i = 2; i < strlen(token); i++)
 						*to++ = token[i];
 					*to++ = '>';
 					*to++ = '}';
@@ -65,7 +67,7 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 					*to++ = ' ';
 					*to++ = '(';
 					bool separate = false;
-					for (unsigned int i = 2; i < strlen(token); i++) {
+					for (i = 2; i < strlen(token); i++) {
 						if (separate) {
 							*to++ = ';';
 							*to++ = ' ';
@@ -85,39 +87,10 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 								}
 							}
 							break;
-						case 'P':
-							separate = true;
-							*to++ = 'p';
-							*to++ = 'l';
-							*to++ = 'u';
-							*to++ = 'r';
-							*to++ = 'a';
-							*to++ = 'l';
-							break;
-						case 'S':
-							separate = true;
-							*to++ = 's';
-							*to++ = 'i';
-							*to++ = 'n';
-							*to++ = 'g';
-							*to++ = 'u';
-							*to++ = 'l';
-							*to++ = 'a';
-							*to++ = 'r';
-							break;
-						case 'A':
-							separate = true;
-							*to++ = 'a';
-							*to++ = 'o';
-							*to++ = 'r';
-							*to++ = 't';
-							*to++ = 'i';
-							*to++ = 's';
-							*to++ = 't';
-							break;
 						default:
-							break;
-							// some token we don't understand
+							for (; i < strlen(token); i++) {
+							       *to++ = token[i];
+							}
 						}
 					}
 					*to++ = ')';
@@ -174,6 +147,42 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 					*to++ = '0';
 					*to++ = ' ';
 					continue;
+				case 'N':
+				        *to++ = '{';
+				        if (!strnicmp(token+2, "Symbol", 6)) {
+					  *to++ = '\\';
+					  *to++ = 'f';
+					  *to++ = '7';
+					  *to++ = ' ';
+					}
+					continue;
+				case 'n':
+					*to++ = '}';
+					continue;
+				case 'S':
+				        *to++ = '{';
+				        *to++ = '\\';
+					*to++ = 's';
+					*to++ = 'u';
+					*to++ = 'p';
+					*to++ = 'e';
+					*to++ = 'r';
+					*to++ = ' ';
+					continue;
+				case 's':
+       				        *to++ = '}';
+					continue;
+				case 'R':
+				        *to++ = '{';
+					*to++ = '\\';
+					*to++ = 'c';
+					*to++ = 'f';
+					*to++ = '6';
+					*to++ = ' ';
+					continue;
+				case 'r':
+				        *to++ = '}';
+					continue;
 				}
 				break;
 			case 'C':			// special character tags
@@ -203,6 +212,47 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 					*to++ = '<';
 				}
 				break;
+			case 'T':			// title formatting
+			  switch(token[1])
+			    {
+			    case 'T':               // Book title begin
+			      *to++ = '{';
+			      *to++ = '\\';
+			      *to++ = 'f';
+			      *to++ = 's';
+			      *to++ = '2';
+			      *to++ = '2';
+			      *to++ = ' ';
+			      continue;
+			    case 't':
+			      *to++ = '}';
+			      continue;
+			    case 'S':
+			      *to++ = '\\';
+			      *to++ = 'p';
+			      *to++ = 'a';
+			      *to++ = 'r';
+			      *to++ = ' ';
+			      *to++ = '{';
+			      *to++ = '\\';
+			      *to++ = 'i';
+			      *to++ = '1';
+			      *to++ = '\\';
+			      *to++ = 'b';
+			      *to++ = '1';
+			      *to++ = ' ';
+			      continue;
+			    case 's':
+			      *to++ = '}';
+			      *to++ = '\\';
+			      *to++ = 'p';
+			      *to++ = 'a';
+			      *to++ = 'r';
+			      *to++ = ' ';
+			      continue;
+			    }
+			  break;
+
 			}
 			continue;
 		}
@@ -212,6 +262,7 @@ char GBFRTF::ProcessText(char *text, int maxlen, const SWKey *key)
 		}
 		else	*to++ = *from;
 	}
+	*to++ = 0;
 	*to = 0;
 	return 0;
 }
