@@ -29,7 +29,7 @@
  *		idisp	- Display object to use for displaying
  */
 
-RawLD::RawLD(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp) : RawStr(ipath), SWLD(iname, idesc, idisp)
+RawLD::RawLD(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp, bool unicode) : RawStr(ipath), SWLD(iname, idesc, idisp, unicode)
 {
 }
 
@@ -78,8 +78,8 @@ void RawLD::strongsPad(char *buf)
 
 char RawLD::getEntry(long away)
 {
-	long  start;
-	unsigned short size;
+	long  start = 0;
+	unsigned short size = 0;
 	char *idxbuf = 0;
 	char retval = 0;
 
@@ -90,9 +90,10 @@ char RawLD::getEntry(long away)
 
 	*entrybuf = 0;
 	if (!(retval = findoffset(buf, &start, &size, away))) {
+		entrySize = size;        // support getEntrySize call
 		if (entrybuf)
 			delete [] entrybuf;
-		entrybuf = new char [ ++size * FILTERPAD ];
+		entrybuf = new char [ ++size * FILTERPAD * ((unicode) ? 9 : 1 ) ];
 		idxbuf   = new char [ size * FILTERPAD ];
 
 		gettext(start, size, idxbuf, entrybuf);
@@ -120,7 +121,7 @@ char RawLD::getEntry(long away)
  */
 
 char *RawLD::getRawEntry() {
-	if (!getEntry()) {
+	if (!getEntry() && !unicode) {
 		preptext(entrybuf);
 	}
 
@@ -154,10 +155,10 @@ SWModule &RawLD::operator +=(int increment)
 
 
 /******************************************************************************
- * RawLD::operator =(POSITION)	- Positions this key if applicable
+ * RawLD::operator =(SW_POSITION)	- Positions this key if applicable
  */
 
-SWModule &RawLD::operator =(POSITION p)
+SWModule &RawLD::operator =(SW_POSITION p)
 {
 	if (!key->Traversable()) {
 		switch (p) {
@@ -172,3 +173,28 @@ SWModule &RawLD::operator =(POSITION p)
 	else	*key = p;
 	return *this;
 }
+
+
+SWModule &RawLD::operator <<(const char *inbuf) {
+	settext(*key, inbuf);
+
+	return *this;
+}
+
+
+SWModule &RawLD::operator <<(const SWKey *inkey) {
+	linkentry(*key, *inkey);
+
+	return *this;
+}
+
+
+/******************************************************************************
+ * RawFiles::deleteEntry	- deletes this entry
+ *
+ * RET: *this
+ */
+
+void RawLD::deleteEntry() {
+	settext(*key, "");
+}
