@@ -14,7 +14,7 @@
  *	idisp	 - Display object to use for displaying
  */
 
-SWLD::SWLD(const char *imodname, const char *imoddesc, SWDisplay *idisp): SWModule(imodname, imoddesc, idisp, "Lexicons / Dictionaries")
+SWLD::SWLD(const char *imodname, const char *imoddesc, SWDisplay *idisp, bool unicode) : SWModule(imodname, imoddesc, idisp, "Lexicons / Dictionaries", unicode)
 {
 	delete key;
 	key = CreateKey();
@@ -44,7 +44,7 @@ SWLD::~SWLD()
  * RET:	pointer to keytext
  */
 
-const char *SWLD::KeyText(char *ikeytext)
+const char *SWLD::KeyText(const char *ikeytext)
 {
 	if (key->Persist() && !ikeytext) {
 		(char *) *this;	// force module key to snap to entry
