@@ -36,11 +36,11 @@
  *	idisp	 - Display object to use for displaying
  */
 
-RawText::RawText(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp) : SWText(iname, idesc, idisp), RawVerse(ipath)
-{
+RawText::RawText(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp, bool unicode)
+		: SWText(iname, idesc, idisp, unicode),
+          RawVerse(ipath) {
+          
 	versebuf = 0;
-	int datfd, idxfd;
-
 	string fname;
 	fname = path;
 	char ch = fname.c_str()[strlen(fname.c_str())-1];
@@ -48,16 +48,13 @@ RawText::RawText(const char *ipath, const char *iname, const char *idesc, SWDisp
 		fname += "/";
 	
 	for (int loop = 0; loop < 2; loop++) {
-		const char *fastidxname =(fname + ((loop)?"ntwords.dat":"otwords.dat")).c_str();
-		datfd = open(fastidxname, O_RDONLY|O_BINARY);
-		fastidxname = (fname + ((loop)?"ntwords.idx":"otwords.idx")).c_str();
-		idxfd = open(fastidxname, O_RDONLY|O_BINARY);
-		if ((datfd > 0) && (idxfd > 0)) {
-			fastSearch[loop] = new RawStr((fname + ((loop)?"ntwords":"otwords")).c_str());
-		}
-		else	fastSearch[loop] = 0;
-		close(idxfd);
-		close(datfd);
+     	fastSearch[loop] = 0;
+		string fastidxname =(fname + ((loop)?"ntwords.dat":"otwords.dat"));
+		if (!access(fastidxname.c_str(), 04)) {
+			fastidxname = (fname + ((loop)?"ntwords.idx":"otwords.idx"));
+			if (!access(fastidxname.c_str(), 04))
+				fastSearch[loop] = new RawStr((fname + ((loop)?"ntwords":"otwords")).c_str());
+        	}
 	}
 }
 
@@ -87,34 +84,37 @@ RawText::~RawText()
  */
 
 char *RawText::getRawEntry() {
-	long  start;
-	unsigned short size;
+	long  start = 0;
+	unsigned short size = 0;
 	VerseKey *key = 0;
-	FilterList::iterator it;
 
 	// see if we have a VerseKey * or decendant
+#ifndef _WIN32_WCE
 	try {
-		key = dynamic_cast<VerseKey *>(this->key);
-	}
-	catch ( ... ) {
+#endif
+		key = SWDYNAMIC_CAST(VerseKey, this->key);
+#ifndef _WIN32_WCE
 	}
+	catch ( ... ) {	}
+#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!key)
 		key = new VerseKey(this->key);
 
 	findoffset(key->Testament(), key->Index(), &start, &size);
-
+	entrySize = size;        // support getEntrySize call
 	if (versebuf)
 		delete [] versebuf;
-	versebuf = new char [ ++size * FILTERPAD ];
 
-	gettext(key->Testament(), start, size, versebuf);
+	versebuf = new char [ (size + 2) * FILTERPAD * ((unicode) ? 9 : 1 ) ];
+	*versebuf = 0;
 
-	for (it = rawfilters.begin(); it != rawfilters.end(); it++) {
-		(*it)->ProcessText(versebuf, size, key);
-	}
+	gettext(key->Testament(), start, (size + 2), versebuf);
 
-	preptext(versebuf);
+	rawFilter(versebuf, size, key);
+
+     if (!unicode)
+		preptext(versebuf);
 
 	if (this->key != key) // free our key if we created a VerseKey
 		delete key;
@@ -205,9 +205,9 @@ char RawText::createSearchFramework() {
 
 	// for old and new testament do...
 	for (int loop = 0; loop < 2; loop++) {
-		if ((datfd = open((fname + ((loop)?"ntwords.dat":"otwords.dat")).c_str(), O_CREAT|O_WRONLY, 00644 )) == -1)
+		if ((datfd = open((fname + ((loop)?"ntwords.dat":"otwords.dat")).c_str(), O_CREAT|O_WRONLY|O_BINARY, 00644 )) == -1)
 			return -1;
-		if ((idxfd = open((fname + ((loop)?"ntwords.idx":"otwords.idx")).c_str(), O_CREAT|O_WRONLY, 00644 )) == -1) {
+		if ((idxfd = open((fname + ((loop)?"ntwords.idx":"otwords.idx")).c_str(), O_CREAT|O_WRONLY|O_BINARY, 00644 )) == -1) {
 			close(datfd);
 			return -1;
 		}
@@ -285,11 +285,14 @@ ListKey &RawText::Search(const char *istr, int searchType, int flags, SWKey *sco
 			// test to see if our scope for this search is bounded by a
 			// VerseKey
 			VerseKey *testKeyType = 0;
+#ifndef _WIN32_WCE
 			try {
-				testKeyType = dynamic_cast<VerseKey *>((scope)?scope:key);
-			}
-			catch ( ... ) {
+#endif
+				testKeyType = SWDYNAMIC_CAST(VerseKey, ((scope)?scope:key));
+#ifndef _WIN32_WCE
 			}
+			catch ( ... ) {}
+#endif
 			// if we don't have a VerseKey * decendant we can't handle
 			// because of scope.
 			// In the future, add bool SWKey::isValid(const char *tryString);
@@ -372,9 +375,9 @@ ListKey &RawText::Search(const char *istr, int searchType, int flags, SWKey *sco
 
 							// get data for this word from database
 							free(idxbuf);
-							idxbuf = (char *)calloc(size+1, 1);
-							datbuf = (char *)calloc(size+1, 1);
-							fastSearch[j]->gettext(start, size, idxbuf, datbuf);
+							idxbuf = (char *)calloc(size+2, 1);
+							datbuf = (char *)calloc(size+2, 1);
+							fastSearch[j]->gettext(start, size + 2, idxbuf, datbuf);
 
 							// we know that the data consists of sizof(long)
 							// records each a valid module position that constains
@@ -419,11 +422,14 @@ ListKey &RawText::Search(const char *istr, int searchType, int flags, SWKey *sco
 
 					// check scope
 					// Try to set our scope key to this verse key
-					*testKeyType = vk;
+					if (scope) {
+						*testKeyType = vk;
 
-					// check to see if it set ok and if so, add to our return list
-					if (*testKeyType == vk)
-						listkey << (const char *) vk;
+						// check to see if it set ok and if so, add to our return list
+						if (*testKeyType == vk)
+							listkey << (const char *) vk;
+					}
+					else listkey << (const char*) vk;
 				}
 			}
 			(*percent)(98, percentUserData);
@@ -453,8 +459,11 @@ ListKey &RawText::Search(const char *istr, int searchType, int flags, SWKey *sco
 	return SWModule::Search(istr, searchType, flags, scope, justCheckIfSupported, percent, percentUserData);
 }
 
-
-RawText &RawText::operator =(POSITION p) {
+#ifdef __VISUALC__
+SWModule &RawText::operator =(SW_POSITION p) {
+#else
+RawText &RawText::operator =(SW_POSITION p) {
+#endif
 	SWModule::operator =(p);
 	return *this;
 }
@@ -463,17 +472,23 @@ RawText &RawText::operator =(POSITION p) {
 SWModule &RawText::operator <<(const char *inbuf) {
 	VerseKey *key = 0;
 	// see if we have a VerseKey * or decendant
+#ifndef _WIN32_WCE
 	try {
-		key = dynamic_cast<VerseKey *>(this->key);
-	}
-	catch ( ... ) {
+#endif
+		key = SWDYNAMIC_CAST(VerseKey, this->key);
+#ifndef _WIN32_WCE
 	}
+	catch ( ... ) {}
+#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!key)
 		key = new VerseKey(this->key);
 
 	settext(key->Testament(), key->Index(), inbuf);
 
+	if (this->key != key) // free our key if we created a VerseKey
+		delete key;
+
 	return *this;
 }
 
@@ -482,27 +497,39 @@ SWModule &RawText::operator <<(const SWKey *inkey) {
 	VerseKey *destkey = 0;
 	const VerseKey *srckey = 0;
 	// see if we have a VerseKey * or decendant
+#ifndef _WIN32_WCE
 	try {
-		destkey = dynamic_cast<VerseKey *>(this->key);
-	}
-	catch ( ... ) {
+#endif
+		destkey = SWDYNAMIC_CAST(VerseKey, this->key);
+#ifndef _WIN32_WCE
 	}
+	catch ( ... ) {}
+#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!destkey)
 		destkey = new VerseKey(this->key);
 
 	// see if we have a VerseKey * or decendant
+#ifndef _WIN32_WCE
 	try {
-		srckey = dynamic_cast<const VerseKey *>(inkey);
-	}
-	catch ( ... ) {
+#endif
+		srckey = SWDYNAMIC_CAST(VerseKey, inkey);
+#ifndef _WIN32_WCE
 	}
+	catch ( ... ) {}
+#endif
 	// if we don't have a VerseKey * decendant, create our own
 	if (!srckey)
 		srckey = new VerseKey(inkey);
 
 	linkentry(destkey->Testament(), destkey->Index(), srckey->Index());
 
+	if (this->key != destkey) // free our key if we created a VerseKey
+		delete destkey;
+
+	if (inkey != srckey) // free our key if we created a VerseKey
+		delete srckey;
+
 	return *this;
 }
 
@@ -517,10 +544,14 @@ void RawText::deleteEntry() {
 
 	VerseKey *key = 0;
 
+#ifndef _WIN32_WCE
 	try {
-		key = dynamic_cast<VerseKey *>(this->key);
+#endif
+		key = SWDYNAMIC_CAST(VerseKey, this->key);
+#ifndef _WIN32_WCE
 	}
 	catch ( ... ) {}
+#endif
 	if (!key)
 		key = new VerseKey(this->key);
 
