@@ -1,8 +1,8 @@
 #include <localemgr.h>
 
-main(int argc, char **argv) {
+int main(int argc, char **argv) {
 	if (argc != 3) {
-		fprintf(stderr, "usage: %s localetest <locale_name> <text>\n", *argv);
+		fprintf(stderr, "usage: %s <locale_name> <text>\n", *argv);
 		exit(-1);
 	}
 
