@@ -3,13 +3,18 @@
 #include <versekey.h>
 
 int main(int argc, char **argv) {
+	SWMgr::debug = true;
 	SWMgr mymgr;
+	cerr << "\n\nprefixPath: " << mymgr.prefixPath;
+	cerr << "\nconfigPath: " << mymgr.configPath << "\n\n";
+
+
 	ModMap::iterator it;
 
 	for (it = mymgr.Modules.begin(); it != mymgr.Modules.end(); it++) {
 		if ((!strcmp((*it).second->Type(), "Biblical Texts")) || (!strcmp((*it).second->Type(), "Commentaries"))) {
 			(*it).second->SetKey("James 1:19");
-			cout << "[" << (*it).second->Name() << "] [" << (*it).second->Description() << "]\n";
+			cout << "[" << (*it).second->Name() << "] (Writable: " << (it->second->isWritable()?"Yes":"No") << " [" << (*it).second->Description() << "]\n";
 			cout << (char *) *(*it).second << "\n\n";
 		}
 	}
